@@ -50,6 +50,7 @@
 #endif  /* HAVE_CONFIG_H */
 
 #include "allheaders.h"
+#include "pix_internal.h"
 
 static PIX *DoBlendTest(PIX *pix, BOX *box, l_uint32 val, l_float32 gamma,
                         l_int32 minval, l_int32 maxval, l_int32 which);
@@ -159,7 +160,7 @@ L_REGPARAMS  *rp;
     pix2 = pixRead("/tmp/lept/alpha/cs2.png");  /* cleaned under transparent */
     n1 = nbytesInFile("/tmp/lept/alpha/cs1.png");
     n2 = nbytesInFile("/tmp/lept/alpha/cs2.png");
-    fprintf(stderr, " Original: %d bytes\n Cleaned: %d bytes\n", n1, n2);
+    lept_stderr(" Original: %d bytes\n Cleaned: %d bytes\n", n1, n2);
     regTestWritePixAndCheck(rp, pix1, IFF_JFIF_JPEG);  /* 9 */
     regTestWritePixAndCheck(rp, pix2, IFF_JFIF_JPEG);  /* 10 */
     pixDisplayWithTitle(pix1, 300, 400, "without alpha", rp->display);
@@ -261,12 +262,14 @@ L_REGPARAMS  *rp;
     lept_free(data);
 
         /* Test ascii serialization/deserialization of colormap with alpha */
-    fp = fopenWriteStream("/tmp/lept/alpha/cmap.4", "w");
-    pixcmapWriteStream(fp, cmap);
-    fclose(fp);
-    fp = fopenReadStream("/tmp/lept/alpha/cmap.4");
-    cmap2 = pixcmapReadStream(fp);
-    fclose(fp);
+    if ((fp = lept_fopen("/tmp/lept/alpha/cmap.4", "wb")) != NULL) {
+        pixcmapWriteStream(fp, cmap);
+        lept_fclose(fp);
+    }
+    if ((fp = lept_fopen("/tmp/lept/alpha/cmap.4", "rb")) != NULL) {
+        cmap2 = pixcmapReadStream(fp);
+        lept_fclose(fp);
+    }
     cmapEqual(cmap, cmap2, 4, &equal);
     regTestCompareValues(rp, TRUE, equal, 0.0);  /* 26 */
     pixcmapDestroy(&cmap2);
