@@ -64,20 +64,19 @@ static const char *seltext = "xxxxxxx"
 int main(int    argc,
          char **argv)
 {
-l_int32      w, h, d, w2, h2, i, ncols, same;
-l_float32    angle, conf;
-BOX         *box;
-BOXA        *boxa1, *boxa2;
-PIX         *pix, *pixs, *pixb, *pixb2;
-PIX         *pix1, *pix2, *pix3, *pix4;
-PIXA        *pixam;  /* mask with a single component over each column */
-PIXA        *pixa, *pixa1, *pixa2;
-PIXAA       *pixaa, *pixaa2;
-SEL         *selsplit;
-static char  mainName[] = "arabic_lines";
+l_int32    w, h, d, w2, h2, i, ncols, same;
+l_float32  angle, conf;
+BOX       *box;
+BOXA      *boxa1, *boxa2;
+PIX       *pix, *pixs, *pixb, *pixb2;
+PIX       *pix1, *pix2, *pix3, *pix4;
+PIXA      *pixam;  /* mask with a single component over each column */
+PIXA      *pixa, *pixa1, *pixa2;
+PIXAA     *pixaa, *pixaa2;
+SEL       *selsplit;
 
     if (argc != 1)
-        return ERROR_INT(" Syntax:  arabic_lines", mainName, 1);
+        return ERROR_INT(" Syntax:  arabic_lines", __func__, 1);
 
     setLeptDebugOK(1);
     lept_mkdir("lept/lineseg");
@@ -92,7 +91,7 @@ static char  mainName[] = "arabic_lines";
         /* Deskew */
     pixb = pixFindSkewAndDeskew(pix, 1, &angle, &conf);
     pixDestroy(&pix);
-    fprintf(stderr, "Skew angle: %7.2f degrees; %6.2f conf\n", angle, conf);
+    lept_stderr("Skew angle: %7.2f degrees; %6.2f conf\n", angle, conf);
     pixaAddPix(pixa, pixb, L_INSERT);
 
         /* Use full image morphology to find columns, at 2x reduction.
@@ -102,7 +101,7 @@ static char  mainName[] = "arabic_lines";
     pix1 = pixMorphCompSequence(pixb2, "c5.500 + o20.20", 0);
     boxa1 = pixConnComp(pix1, &pixam, 8);
     ncols = boxaGetCount(boxa1);
-    fprintf(stderr, "Num columns: %d\n", ncols);
+    lept_stderr("Num columns: %d\n", ncols);
     pixaAddPix(pixa, pix1, L_INSERT);
     boxaDestroy(&boxa1);
 
@@ -128,8 +127,7 @@ static char  mainName[] = "arabic_lines";
         pixaaAddBox(pixaa, box, L_INSERT);
         pix4 = pixaDisplayRandomCmap(pixa1, 0, 0);
         pixaAddPix(pixa, pix4, L_INSERT);
-        fprintf(stderr, "Num textlines in col %d: %d\n", i,
-                boxaGetCount(boxa2));
+        lept_stderr("Num textlines in col %d: %d\n", i, boxaGetCount(boxa2));
         pixDestroy(&pix2);
         pixDestroy(&pix3);
         boxaDestroy(&boxa2);
@@ -153,7 +151,7 @@ static char  mainName[] = "arabic_lines";
     filesAreIdentical("/tmp/lept/lineseg/pixaa", "/tmp/lept/lineseg/pixaa2",
                       &same);
     if (!same)
-       L_ERROR("pixaa I/O failure\n", mainName);
+       L_ERROR("pixaa I/O failure\n", __func__);
     pixaaDestroy(&pixaa2);
 
         /* Test pixaa display */
