@@ -30,6 +30,7 @@
  *
  *      Locate text baselines in an image
  *           NUMA     *pixFindBaselines()
+ *           NUMA     *pixFindBaselinesGen()
  *
  *      Projective transform to remove local skew
  *           PIX      *pixDeskewLocal()
@@ -54,20 +55,26 @@
 #include <math.h>
 #include "allheaders.h"
 
-    /* Min to travel after finding max before abandoning peak */
-static const l_int32  MinDistInPeak = 35;
+    /* Default minimum textblock width */
+static const l_int32  DefaultMinBlockWidth = 80;
 
-    /* Thresholds for peaks and zeros, relative to the max peak */
-static const l_int32  PeakThresholdRatio = 20;
+    /* Minimum distance to travel after finding max before abandoning peak.
+     * If MinDistFromPeak < 25, this risks bogus lines at the xheight. */
+static const l_int32  MinDistFromPeak = 30;
+
+    /* Thresholds for peaks and zeros, relative to the max peak.
+     * If PeakThresholdRatio < 40, this risks not identifying lines.
+     * Results appear insensitive to the value of ZeroThresholdRatio.  */
+static const l_int32  PeakThresholdRatio = 80;
 static const l_int32  ZeroThresholdRatio = 100;
 
     /* Default values for determining local skew */
 static const l_int32  DefaultSlices = 10;
 static const l_int32  DefaultSweepReduction = 2;
 static const l_int32  DefaultBsReduction = 1;
-static const l_float32  DefaultSweepRange = 5.;   /* degrees */
-static const l_float32  DefaultSweepDelta = 1.;   /* degrees */
-static const l_float32  DefaultMinbsDelta = 0.01;   /* degrees */
+static const l_float32  DefaultSweepRange = 5.;     /* degrees */
+static const l_float32  DefaultSweepDelta = 1.;     /* degrees */
+static const l_float32  DefaultMinbsDelta = 0.01f;  /* degrees */
 
     /* Overlap slice fraction added to top and bottom of each slice */
 static const l_float32  OverlapFraction = 0.5;
@@ -90,27 +97,8 @@ static const l_float32  MinAllowedConfidence = 3.0;
  *
  * <pre>
  * Notes:
- *      (1) Input binary image must have text lines already aligned
- *          horizontally.  This can be done by either rotating the
- *          image with pixDeskew(), or, if a projective transform
- *          is required, by doing pixDeskewLocal() first.
- *      (2) Input null for &pta if you don't want this returned.
- *          The pta will come in pairs of points (left and right end
- *          of each baseline).
- *      (3) Caution: this will not work properly on text with multiple
- *          columns, where the lines are not aligned between columns.
- *          If there are multiple columns, they should be extracted
- *          separately before finding the baselines.
- *      (4) This function constructs different types of output
- *          for baselines; namely, a set of raster line values and
- *          a set of end points of each baseline.
- *      (5) This function was designed to handle short and long text lines
- *          without using dangerous thresholds on the peak heights.  It does
- *          this by combining the differential signal with a morphological
- *          analysis of the locations of the text lines.  One can also
- *          combine this data to normalize the peak heights, by weighting
- *          the differential signal in the region of each baseline
- *          by the inverse of the width of the text line found there.
+ *      (1) This is a simplified interface to pixFindBaselinesGen().
+ *          See Notes there.
  * </pre>
  */
 NUMA *
@@ -118,9 +106,64 @@ pixFindBaselines(PIX   *pixs,
                  PTA  **ppta,
                  PIXA  *pixadb)
 {
+NUMA  *na;
+
+    if ((na = pixFindBaselinesGen(pixs, DefaultMinBlockWidth,
+                                  ppta, pixadb)) == NULL)
+        return (NUMA *)ERROR_PTR("na not returned", __func__, NULL);
+
+    return na;
+}
+
+/*!
+ * \brief   pixFindBaselinesGen()
+ *
+ * \param[in]    pixs     1 bpp, 300 ppi
+ * \param[in]    minw     approx min block width returned baselines, in pixels
+ * \param[out]   ppta     [optional] pairs of pts corresponding to
+ *                        approx. ends of each text line
+ * \param[in]    pixadb   for debug output; use NULL to skip
+ * \return  na of baseline y values, or NULL on error
+ *
+ * <pre>
+ * Notes:
+ *      (1) Input binary image must have text lines already aligned
+ *          horizontally.  This can be done by either rotating the
+ *          image with pixDeskew(), or, if a projective transform
+ *          is required, by doing pixDeskewLocal() first.
+ *      (2) Input null for &pta if you don't want this returned.
+ *          The pta will come in pairs of points (left and right end
+ *          of each baseline).
+ *      (3) Very short text blocks are ignored.  Use the parameter %minw
+ *          to specify the (approx.) minimum length baseline for a text block
+ *          that is returned.  Suggest using minw = 80 pixels to skip small
+ *          text blocks consisting of up to 3 characters.
+ *      (4) This function returns the locations of baselines for which
+ *          the end points of the the text are found.  Return of those
+ *          end points is optional.
+ *      (5) This function was designed to identify short and long text lines
+ *          without using dangerous thresholds on the peak heights.  It does
+ *          this by combining the differential signal with a morphological
+ *          analysis of the locations of the text lines.  One can also
+ *          combine this data to normalize the peak heights, by weighting
+ *          the differential signal in the region of each baseline
+ *          by the inverse of the width of the text line found there.
+ *      (6) Caution: this will not work properly on text with multiple
+ *          columns, where the lines are not aligned between columns.
+ *          If there are multiple columns, they should be extracted
+ *          separately before finding the baselines.
+ * </pre>
+ */
+NUMA *
+pixFindBaselinesGen(PIX     *pixs,
+                    l_int32  minw,
+                    PTA    **ppta,
+                    PIXA    *pixadb)
+{
+char       cmd[64];
 l_int32    h, i, j, nbox, val1, val2, ndiff, bx, by, bw, bh;
 l_int32    imaxloc, peakthresh, zerothresh, inpeak;
-l_int32    mintosearch, max, maxloc, nloc, locval;
+l_int32    mintosearch, max, maxloc, nloc, locval, found, nremoved;
 l_int32   *array;
 l_float32  maxval;
 BOXA      *boxa1, *boxa2, *boxa3;
@@ -129,11 +172,12 @@ NUMA      *nasum, *nadiff, *naloc, *naval;
 PIX       *pix1, *pix2;
 PTA       *pta;
 
-    PROCNAME("pixFindBaselines");
-
     if (ppta) *ppta = NULL;
     if (!pixs || pixGetDepth(pixs) != 1)
-        return (NUMA *)ERROR_PTR("pixs undefined or not 1 bpp", procName, NULL);
+        return (NUMA *)ERROR_PTR("pixs undefined or not 1 bpp", __func__, NULL);
+
+        /* minw / 6 must be >= 1 */
+    if (minw < 6) minw = 6;
 
         /* Close up the text characters, removing noise */
     pix1 = pixMorphSequence(pixs, "c25.1 + e15.1", 0);
@@ -145,7 +189,7 @@ PTA       *pta;
          * The high positive-going peaks are the baselines */
     if ((nasum = pixCountPixelsByRow(pix1, NULL)) == NULL) {
         pixDestroy(&pix1);
-        return (NUMA *)ERROR_PTR("nasum not made", procName, NULL);
+        return (NUMA *)ERROR_PTR("nasum not made", __func__, NULL);
     }
     h = pixGetHeight(pixs);
     nadiff = numaCreate(h);
@@ -182,8 +226,8 @@ PTA       *pta;
         if (inpeak == FALSE) {
             if (array[i] > peakthresh) {  /* transition to in-peak */
                 inpeak = TRUE;
-                mintosearch = i + MinDistInPeak; /* accept no zeros
-                                               * between i and mintosearch */
+                mintosearch = i + MinDistFromPeak; /* accept no zeros
+                                                 * between i and mintosearch */
                 max = array[i];
                 maxloc = i;
             }
@@ -191,8 +235,9 @@ PTA       *pta;
             if (array[i] > max) {
                 max = array[i];
                 maxloc = i;
-                mintosearch = i + MinDistInPeak;
-            } else if (i > mintosearch && array[i] <= zerothresh) {  /* leave */
+                mintosearch = i + MinDistFromPeak;
+            } else if (i >= mintosearch && array[i] <= zerothresh) {
+                                     /* leave and store previous peak */
                 inpeak = FALSE;
                 numaAddNumber(naval, max);
                 numaAddNumber(naloc, maxloc);
@@ -219,9 +264,11 @@ PTA       *pta;
     numaDestroy(&naval);
 
         /* Generate an approximate profile of text line width.
-         * First, filter the boxes of text, where there may be
-         * more than one box for a given textline. */
-    pix2 = pixMorphSequence(pix1, "r11 + c20.1 + o30.1 +c1.3", 0);
+         * First, consolidate and filter the boxes of text.
+         * The horizontal opening removes text blocks with width
+         * less than about 'minw' pixels at full resolution. */
+    snprintf(cmd, sizeof(cmd), "r11 + c20.1 + o%d.1", minw / 6);
+    pix2 = pixMorphSequence(pix1, cmd, 0);
     if (pixadb) pixaAddPix(pixadb, pix2, L_COPY);
     boxa1 = pixConnComp(pix2, NULL, 4);
     pixDestroy(&pix1);
@@ -229,7 +276,7 @@ PTA       *pta;
     if (boxaGetCount(boxa1) == 0) {
         numaDestroy(&naloc);
         boxaDestroy(&boxa1);
-        L_INFO("no components after filtering\n", procName);
+        L_INFO("no components after filtering\n", __func__);
         return NULL;
     }
     boxa2 = boxaTransform(boxa1, 0, 0, 4., 4.);
@@ -237,29 +284,45 @@ PTA       *pta;
     boxaDestroy(&boxa1);
     boxaDestroy(&boxa2);
 
-        /* Optionally, find the baseline segments */
-    pta = NULL;
-    if (ppta) {
-        pta = ptaCreate(0);
-        *ppta = pta;
-    }
-    if (pta) {
-      nloc = numaGetCount(naloc);
-      nbox = boxaGetCount(boxa3);
-      for (i = 0; i < nbox; i++) {
-          boxaGetBoxGeometry(boxa3, i, &bx, &by, &bw, &bh);
-          for (j = 0; j < nloc; j++) {
-              numaGetIValue(naloc, j, &locval);
-              if (L_ABS(locval - (by + bh)) > 25)
-                  continue;
-              ptaAddPt(pta, bx, locval);
-              ptaAddPt(pta, bx + bw, locval);
-              break;
-          }
-      }
+        /* For each baseline, find the corresponding textboxes.
+         * There may be more than one textbox to a baseline.
+         * Bogus textboxes of very small height may have been
+         * generated, and these are removed.  Bogus textboxes can
+         * also be eliminated if the bottom is too far from any of
+         * the baselines.  If there are no valid textboxes for a
+         * baseline, that baseline is removed.
+         * Note that the boxes have been expanded from 4x reduction,
+         * so box parameters are multiples of 4. */
+    pta = ptaCreate(0);
+    nloc = numaGetCount(naloc);
+    nbox = boxaGetCount(boxa3);
+    nremoved = 0;  /* keeps track of baselines removed */
+    for (i = 0; i < nloc; i++) {
+        numaGetIValue(naloc, i, &locval);
+        found = FALSE;
+        for (j = 0; j < nbox; j++) {
+            boxaGetBoxGeometry(boxa3, j, &bx, &by, &bw, &bh);
+            if (bh > 12 && L_ABS(locval - (by + bh)) <= 24) {
+                ptaAddPt(pta, bx, locval);
+                ptaAddPt(pta, bx + bw, locval);
+                found = TRUE;
+            }
+        }
+        if (!found) {  /* no textbox corresponding to this baseline */
+            L_INFO("short baseline %d at y = %d removed\n", __func__,
+                    i + nremoved, locval);
+            numaRemoveNumber(naloc, i);
+            nremoved++;
+            i--;
+            nloc--;
+        }
     }
     boxaDestroy(&boxa3);
 
+    if (ppta)
+        *ppta = pta;
+    else
+        ptaDestroy(&pta);
     if (pixadb && pta) {  /* display baselines */
         l_int32  npts, x1, y1, x2, y2;
         pix1 = pixConvertTo32(pixs);
@@ -333,10 +396,8 @@ l_int32    ret;
 PIX       *pixd;
 PTA       *ptas, *ptad;
 
-    PROCNAME("pixDeskewLocal");
-
     if (!pixs || pixGetDepth(pixs) != 1)
-        return (PIX *)ERROR_PTR("pixs undefined or not 1 bpp", procName, NULL);
+        return (PIX *)ERROR_PTR("pixs undefined or not 1 bpp", __func__, NULL);
 
         /* Skew array gives skew angle (deg) as fctn of raster line
          * where it intersects the LHS of the image */
@@ -344,7 +405,7 @@ PTA       *ptas, *ptad;
                                    sweeprange, sweepdelta, minbsdelta,
                                    &ptas, &ptad);
     if (ret != 0)
-        return (PIX *)ERROR_PTR("transform pts not found", procName, NULL);
+        return (PIX *)ERROR_PTR("transform pts not found", __func__, NULL);
 
         /* Use a projective transform */
     pixd = pixProjectiveSampledPta(pixs, ptad, ptas, L_BRING_IN_WHITE);
@@ -405,13 +466,11 @@ l_float32  deg2rad, angr, angd, dely;
 NUMA      *naskew;
 PTA       *ptas, *ptad;
 
-    PROCNAME("pixGetLocalSkewTransform");
-
     if (!pptas || !pptad)
-        return ERROR_INT("&ptas and &ptad not defined", procName, 1);
+        return ERROR_INT("&ptas and &ptad not defined", __func__, 1);
     *pptas = *pptad = NULL;
     if (!pixs || pixGetDepth(pixs) != 1)
-        return ERROR_INT("pixs not defined or not 1 bpp", procName, 1);
+        return ERROR_INT("pixs not defined or not 1 bpp", __func__, 1);
     if (nslices < 2 || nslices > 20)
         nslices = DefaultSlices;
     if (redsweep < 1 || redsweep > 8)
@@ -429,9 +488,9 @@ PTA       *ptas, *ptad;
                                    sweeprange, sweepdelta, minbsdelta,
                                    NULL, NULL, 0);
     if (!naskew)
-        return ERROR_INT("naskew not made", procName, 1);
+        return ERROR_INT("naskew not made", __func__, 1);
 
-    deg2rad = 3.14159265 / 180.;
+    deg2rad = 3.14159265f / 180.f;
     w = pixGetWidth(pixs);
     h = pixGetHeight(pixs);
     ptas = ptaCreate(4);
@@ -530,10 +589,8 @@ NUMA      *naskew, *nax, *nay;
 PIX       *pix;
 PTA       *pta;
 
-    PROCNAME("pixGetLocalSkewAngles");
-
     if (!pixs || pixGetDepth(pixs) != 1)
-        return (NUMA *)ERROR_PTR("pixs undefined or not 1 bpp", procName, NULL);
+        return (NUMA *)ERROR_PTR("pixs undefined or not 1 bpp", __func__, NULL);
     if (nslices < 2 || nslices > 20)
         nslices = DefaultSlices;
     if (redsweep < 1 || redsweep > 8)
@@ -568,7 +625,7 @@ PTA       *pta;
         /* Do linear least squares fit */
     if ((npts = ptaGetCount(pta)) < 2) {
         ptaDestroy(&pta);
-        return (NUMA *)ERROR_PTR("can't fit skew", procName, NULL);
+        return (NUMA *)ERROR_PTR("can't fit skew", __func__, NULL);
     }
     ptaGetLinearLSF(pta, &a, &b, NULL);
     if (pa) *pa = a;
