@@ -461,12 +461,10 @@ dewarpCreate(PIX     *pixs,
 {
 L_DEWARP  *dew;
 
-    PROCNAME("dewarpCreate");
-
     if (!pixs)
-        return (L_DEWARP *)ERROR_PTR("pixs not defined", procName, NULL);
+        return (L_DEWARP *)ERROR_PTR("pixs not defined", __func__, NULL);
     if (pixGetDepth(pixs) != 1)
-        return (L_DEWARP *)ERROR_PTR("pixs not 1 bpp", procName, NULL);
+        return (L_DEWARP *)ERROR_PTR("pixs not 1 bpp", __func__, NULL);
 
     dew = (L_DEWARP *)LEPT_CALLOC(1, sizeof(L_DEWARP));
     dew->pixs = pixClone(pixs);
@@ -519,10 +517,8 @@ dewarpDestroy(L_DEWARP  **pdew)
 {
 L_DEWARP  *dew;
 
-    PROCNAME("dewarpDestroy");
-
     if (pdew == NULL) {
-        L_WARNING("ptr address is null!\n", procName);
+        L_WARNING("ptr address is null!\n", __func__);
         return;
     }
     if ((dew = *pdew) == NULL)
@@ -585,26 +581,24 @@ dewarpaCreate(l_int32  nptrs,
 {
 L_DEWARPA  *dewa;
 
-    PROCNAME("dewarpaCreate");
-
     if (nptrs <= 0)
         nptrs = InitialPtrArraySize;
     if (nptrs > MaxPtrArraySize)
-        return (L_DEWARPA *)ERROR_PTR("too many pages", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("too many pages", __func__, NULL);
     if (redfactor != 1 && redfactor != 2)
         return (L_DEWARPA *)ERROR_PTR("redfactor not in {1,2}",
-                                      procName, NULL);
+                                      __func__, NULL);
     if (sampling == 0) {
          sampling = DefaultArraySampling;
     } else if (sampling < MinArraySampling) {
-         L_WARNING("sampling too small; setting to %d\n", procName,
+         L_WARNING("sampling too small; setting to %d\n", __func__,
                    MinArraySampling);
          sampling = MinArraySampling;
     }
     if (minlines == 0) {
         minlines = DefaultMinLines;
     } else if (minlines < MinMinLines) {
-        L_WARNING("minlines too small; setting to %d\n", procName,
+        L_WARNING("minlines too small; setting to %d\n", __func__,
                   MinMinLines);
         minlines = DefaultMinLines;
     }
@@ -616,7 +610,7 @@ L_DEWARPA  *dewa;
     dewa->dewarpcache = (L_DEWARP **)LEPT_CALLOC(nptrs, sizeof(L_DEWARPA *));
     if (!dewa->dewarp || !dewa->dewarpcache) {
         dewarpaDestroy(&dewa);
-        return (L_DEWARPA *)ERROR_PTR("dewarp ptrs not made", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("dewarp ptrs not made", __func__, NULL);
     }
     dewa->nalloc = nptrs;
     dewa->sampling = sampling;
@@ -677,15 +671,13 @@ L_DEWARP   *dew;
 L_DEWARPA  *dewa;
 PIX        *pixt;
 
-    PROCNAME("dewarpaCreateFromPixacomp");
-
     if (!pixac)
-        return (L_DEWARPA *)ERROR_PTR("pixac not defined", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("pixac not defined", __func__, NULL);
 
     nptrs = pixacompGetCount(pixac);
     if ((dewa = dewarpaCreate(pixacompGetOffset(pixac) + nptrs,
                               sampling, 1, minlines, maxdist)) == NULL)
-        return (L_DEWARPA *)ERROR_PTR("dewa not made", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("dewa not made", __func__, NULL);
     dewarpaUseBothArrays(dewa, useboth);
 
     for (i = 0; i < nptrs; i++) {
@@ -695,7 +687,7 @@ PIX        *pixt;
             dew = dewarpCreate(pixt, pageno);
             pixDestroy(&pixt);
             if (!dew) {
-                ERROR_INT("unable to make dew!", procName, 1);
+                ERROR_INT("unable to make dew!", __func__, 1);
                 continue;
             }
 
@@ -706,7 +698,7 @@ PIX        *pixt;
             dewarpBuildPageModel(dew, NULL);
             if (!dew->vsuccess) {  /* will need to use model from nearby page */
                 dewarpaDestroyDewarp(dewa, pageno);
-                L_ERROR("unable to build model for page %d\n", procName, i);
+                L_ERROR("unable to build model for page %d\n", __func__, i);
                 continue;
             }
                 /* Remove all extraneous data */
@@ -733,10 +725,8 @@ l_int32     i;
 L_DEWARP   *dew;
 L_DEWARPA  *dewa;
 
-    PROCNAME("dewarpaDestroy");
-
     if (pdewa == NULL) {
-        L_WARNING("ptr address is null!\n", procName);
+        L_WARNING("ptr address is null!\n", __func__);
         return;
     }
     if ((dewa = *pdewa) == NULL)
@@ -771,14 +761,12 @@ dewarpaDestroyDewarp(L_DEWARPA  *dewa,
 {
 L_DEWARP   *dew;
 
-    PROCNAME("dewarpaDestroyDewarp");
-
     if (!dewa)
-        return ERROR_INT("dewa or dew not defined", procName, 1);
+        return ERROR_INT("dewa or dew not defined", __func__, 1);
     if (pageno < 0 || pageno > dewa->maxpage)
-        return ERROR_INT("page out of bounds", procName, 1);
+        return ERROR_INT("page out of bounds", __func__, 1);
     if ((dew = dewa->dewarp[pageno]) == NULL)
-        return ERROR_INT("dew not defined", procName, 1);
+        return ERROR_INT("dew not defined", __func__, 1);
 
     dewarpDestroy(&dew);
     dewa->dewarp[pageno] = NULL;
@@ -815,17 +803,15 @@ dewarpaInsertDewarp(L_DEWARPA  *dewa,
 l_int32    pageno, n, newsize;
 L_DEWARP  *prevdew;
 
-    PROCNAME("dewarpaInsertDewarp");
-
     if (!dewa)
-        return ERROR_INT("dewa not defined", procName, 1);
+        return ERROR_INT("dewa not defined", __func__, 1);
     if (!dew)
-        return ERROR_INT("dew not defined", procName, 1);
+        return ERROR_INT("dew not defined", __func__, 1);
 
     dew->dewa = dewa;
     pageno = dew->pageno;
     if (pageno > MaxPtrArraySize)
-        return ERROR_INT("too many pages", procName, 1);
+        return ERROR_INT("too many pages", __func__, 1);
     if (pageno > dewa->maxpage)
         dewa->maxpage = pageno;
     dewa->modelsready = 0;  /* force re-evaluation at application time */
@@ -839,7 +825,7 @@ L_DEWARP  *prevdew;
         newsize = 2 * n;
     if (newsize > n) {
         if (dewarpaExtendArraysToSize(dewa, newsize))
-            return ERROR_INT("extension failed", procName, 1);
+            return ERROR_INT("extension failed", __func__, 1);
     }
 
     if ((prevdew = dewarpaGetDewarp(dewa, pageno)) != NULL)
@@ -879,21 +865,19 @@ static l_int32
 dewarpaExtendArraysToSize(L_DEWARPA  *dewa,
                          l_int32     size)
 {
-    PROCNAME("dewarpaExtendArraysToSize");
-
     if (!dewa)
-        return ERROR_INT("dewa not defined", procName, 1);
+        return ERROR_INT("dewa not defined", __func__, 1);
 
     if (size > dewa->nalloc) {
         if ((dewa->dewarp = (L_DEWARP **)reallocNew((void **)&dewa->dewarp,
                 sizeof(L_DEWARP *) * dewa->nalloc,
                 size * sizeof(L_DEWARP *))) == NULL)
-            return ERROR_INT("new ptr array not returned", procName, 1);
+            return ERROR_INT("new ptr array not returned", __func__, 1);
         if ((dewa->dewarpcache =
                 (L_DEWARP **)reallocNew((void **)&dewa->dewarpcache,
                 sizeof(L_DEWARP *) * dewa->nalloc,
                 size * sizeof(L_DEWARP *))) == NULL)
-            return ERROR_INT("new ptr cache array not returned", procName, 1);
+            return ERROR_INT("new ptr cache array not returned", __func__, 1);
         dewa->nalloc = size;
     }
     return 0;
@@ -911,13 +895,11 @@ L_DEWARP *
 dewarpaGetDewarp(L_DEWARPA  *dewa,
                  l_int32     index)
 {
-    PROCNAME("dewarpaGetDewarp");
-
     if (!dewa)
-        return (L_DEWARP *)ERROR_PTR("dewa not defined", procName, NULL);
+        return (L_DEWARP *)ERROR_PTR("dewa not defined", __func__, NULL);
     if (index < 0 || index > dewa->maxpage) {
         L_ERROR("index = %d is invalid; max index = %d\n",
-                procName, index, dewa->maxpage);
+                __func__, index, dewa->maxpage);
         return NULL;
     }
 
@@ -985,10 +967,8 @@ dewarpaSetCurvatures(L_DEWARPA  *dewa,
                      l_int32     max_diff_edgecurv,
                      l_int32     max_edgeslope)
 {
-    PROCNAME("dewarpaSetCurvatures");
-
     if (!dewa)
-        return ERROR_INT("dewa not defined", procName, 1);
+        return ERROR_INT("dewa not defined", __func__, 1);
 
     if (max_linecurv == -1)
         dewa->max_linecurv = DefaultMaxLineCurv;
@@ -1044,10 +1024,8 @@ l_ok
 dewarpaUseBothArrays(L_DEWARPA  *dewa,
                      l_int32     useboth)
 {
-    PROCNAME("dewarpaUseBothArrays");
-
     if (!dewa)
-        return ERROR_INT("dewa not defined", procName, 1);
+        return ERROR_INT("dewa not defined", __func__, 1);
 
     dewa->useboth = useboth;
     dewa->modelsready = 0;  /* force validation */
@@ -1083,10 +1061,8 @@ l_ok
 dewarpaSetCheckColumns(L_DEWARPA  *dewa,
                        l_int32     check_columns)
 {
-    PROCNAME("dewarpaSetCheckColumns");
-
     if (!dewa)
-        return ERROR_INT("dewa not defined", procName, 1);
+        return ERROR_INT("dewa not defined", __func__, 1);
 
     dewa->check_columns = check_columns;
     return 0;
@@ -1109,10 +1085,8 @@ l_ok
 dewarpaSetMaxDistance(L_DEWARPA  *dewa,
                       l_int32     maxdist)
 {
-    PROCNAME("dewarpaSetMaxDistance");
-
     if (!dewa)
-        return ERROR_INT("dewa not defined", procName, 1);
+        return ERROR_INT("dewa not defined", __func__, 1);
 
     dewa->maxdist = maxdist;
     dewa->modelsready = 0;  /* force validation */
@@ -1135,16 +1109,16 @@ dewarpRead(const char  *filename)
 FILE      *fp;
 L_DEWARP  *dew;
 
-    PROCNAME("dewarpRead");
-
     if (!filename)
-        return (L_DEWARP *)ERROR_PTR("filename not defined", procName, NULL);
+        return (L_DEWARP *)ERROR_PTR("filename not defined", __func__, NULL);
     if ((fp = fopenReadStream(filename)) == NULL)
-        return (L_DEWARP *)ERROR_PTR("stream not opened", procName, NULL);
+        return (L_DEWARP *)ERROR_PTR_1("stream not opened",
+                                       filename, __func__, NULL);
 
     if ((dew = dewarpReadStream(fp)) == NULL) {
         fclose(fp);
-        return (L_DEWARP *)ERROR_PTR("dew not read", procName, NULL);
+        return (L_DEWARP *)ERROR_PTR_1("dew not read",
+                                       filename, __func__, NULL);
     }
 
     fclose(fp);
@@ -1176,61 +1150,59 @@ l_int32    version, sampling, redfactor, minlines, pageno, hasref, refpage;
 l_int32    w, h, nx, ny, vdispar, hdispar, nlines;
 l_int32    mincurv, maxcurv, leftslope, rightslope, leftcurv, rightcurv;
 L_DEWARP  *dew;
-FPIX      *fpixv, *fpixh;
-
-    PROCNAME("dewarpReadStream");
+FPIX      *fpixv = NULL, *fpixh = NULL;
 
     if (!fp)
-        return (L_DEWARP *)ERROR_PTR("stream not defined", procName, NULL);
+        return (L_DEWARP *)ERROR_PTR("stream not defined", __func__, NULL);
 
     if (fscanf(fp, "\nDewarp Version %d\n", &version) != 1)
-        return (L_DEWARP *)ERROR_PTR("not a dewarp file", procName, NULL);
+        return (L_DEWARP *)ERROR_PTR("not a dewarp file", __func__, NULL);
     if (version != DEWARP_VERSION_NUMBER)
-        return (L_DEWARP *)ERROR_PTR("invalid dewarp version", procName, NULL);
+        return (L_DEWARP *)ERROR_PTR("invalid dewarp version", __func__, NULL);
     if (fscanf(fp, "pageno = %d\n", &pageno) != 1)
-        return (L_DEWARP *)ERROR_PTR("read fail for pageno", procName, NULL);
+        return (L_DEWARP *)ERROR_PTR("read fail for pageno", __func__, NULL);
     if (fscanf(fp, "hasref = %d, refpage = %d\n", &hasref, &refpage) != 2)
         return (L_DEWARP *)ERROR_PTR("read fail for hasref, refpage",
-                                     procName, NULL);
+                                     __func__, NULL);
     if (fscanf(fp, "sampling = %d, redfactor = %d\n", &sampling, &redfactor)
                != 2)
         return (L_DEWARP *)ERROR_PTR("read fail for sampling/redfactor",
-                                     procName, NULL);
+                                     __func__, NULL);
     if (fscanf(fp, "nlines = %d, minlines = %d\n", &nlines, &minlines) != 2)
         return (L_DEWARP *)ERROR_PTR("read fail for nlines/minlines",
-                                     procName, NULL);
+                                     __func__, NULL);
     if (fscanf(fp, "w = %d, h = %d\n", &w, &h) != 2)
-        return (L_DEWARP *)ERROR_PTR("read fail for w, h", procName, NULL);
+        return (L_DEWARP *)ERROR_PTR("read fail for w, h", __func__, NULL);
     if (fscanf(fp, "nx = %d, ny = %d\n", &nx, &ny) != 2)
-        return (L_DEWARP *)ERROR_PTR("read fail for nx, ny", procName, NULL);
+        return (L_DEWARP *)ERROR_PTR("read fail for nx, ny", __func__, NULL);
     if (fscanf(fp, "vert_dispar = %d, horiz_dispar = %d\n", &vdispar, &hdispar)
                != 2)
-        return (L_DEWARP *)ERROR_PTR("read fail for flags", procName, NULL);
+        return (L_DEWARP *)ERROR_PTR("read fail for flags", __func__, NULL);
     if (vdispar) {
         if (fscanf(fp, "min line curvature = %d, max line curvature = %d\n",
                    &mincurv, &maxcurv) != 2)
             return (L_DEWARP *)ERROR_PTR("read fail for mincurv & maxcurv",
-                                         procName, NULL);
+                                         __func__, NULL);
     }
     if (hdispar) {
         if (fscanf(fp, "left edge slope = %d, right edge slope = %d\n",
                    &leftslope, &rightslope) != 2)
             return (L_DEWARP *)ERROR_PTR("read fail for leftslope & rightslope",
-                                         procName, NULL);
+                                         __func__, NULL);
         if (fscanf(fp, "left edge curvature = %d, right edge curvature = %d\n",
                    &leftcurv, &rightcurv) != 2)
             return (L_DEWARP *)ERROR_PTR("read fail for leftcurv & rightcurv",
-                                         procName, NULL);
+                                         __func__, NULL);
     }
     if (vdispar) {
         if ((fpixv = fpixReadStream(fp)) == NULL)
             return (L_DEWARP *)ERROR_PTR("read fail for vdispar",
-                                         procName, NULL);
+                                         __func__, NULL);
     }
     if (hdispar) {
         if ((fpixh = fpixReadStream(fp)) == NULL)
             return (L_DEWARP *)ERROR_PTR("read fail for hdispar",
-                                         procName, NULL);
+                                         __func__, NULL);
     }
     getc(fp);
 
@@ -1281,16 +1253,14 @@ dewarpReadMem(const l_uint8  *data,
 FILE      *fp;
 L_DEWARP  *dew;
 
-    PROCNAME("dewarpReadMem");
-
     if (!data)
-        return (L_DEWARP *)ERROR_PTR("data not defined", procName, NULL);
+        return (L_DEWARP *)ERROR_PTR("data not defined", __func__, NULL);
     if ((fp = fopenReadFromMemory(data, size)) == NULL)
-        return (L_DEWARP *)ERROR_PTR("stream not opened", procName, NULL);
+        return (L_DEWARP *)ERROR_PTR("stream not opened", __func__, NULL);
 
     dew = dewarpReadStream(fp);
     fclose(fp);
-    if (!dew) L_ERROR("dew not read\n", procName);
+    if (!dew) L_ERROR("dew not read\n", __func__);
     return dew;
 }
 
@@ -1309,19 +1279,17 @@ dewarpWrite(const char  *filename,
 l_int32  ret;
 FILE    *fp;
 
-    PROCNAME("dewarpWrite");
-
     if (!filename)
-        return ERROR_INT("filename not defined", procName, 1);
+        return ERROR_INT("filename not defined", __func__, 1);
     if (!dew)
-        return ERROR_INT("dew not defined", procName, 1);
+        return ERROR_INT("dew not defined", __func__, 1);
 
     if ((fp = fopenWriteStream(filename, "wb")) == NULL)
-        return ERROR_INT("stream not opened", procName, 1);
+        return ERROR_INT_1("stream not opened", filename, __func__, 1);
     ret = dewarpWriteStream(fp, dew);
     fclose(fp);
     if (ret)
-        return ERROR_INT("dew not written to stream", procName, 1);
+        return ERROR_INT_1("dew not written to stream", filename, __func__, 1);
     return 0;
 }
 
@@ -1346,12 +1314,10 @@ dewarpWriteStream(FILE      *fp,
 {
 l_int32  vdispar, hdispar;
 
-    PROCNAME("dewarpWriteStream");
-
     if (!fp)
-        return ERROR_INT("stream not defined", procName, 1);
+        return ERROR_INT("stream not defined", __func__, 1);
     if (!dew)
-        return ERROR_INT("dew not defined", procName, 1);
+        return ERROR_INT("dew not defined", __func__, 1);
 
     fprintf(fp, "\nDewarp Version %d\n", DEWARP_VERSION_NUMBER);
     fprintf(fp, "pageno = %d\n", dew->pageno);
@@ -1378,7 +1344,7 @@ l_int32  vdispar, hdispar;
     fprintf(fp, "\n");
 
     if (!vdispar)
-        L_WARNING("no disparity arrays!\n", procName);
+        L_WARNING("no disparity arrays!\n", __func__);
     return 0;
 }
 
@@ -1404,32 +1370,30 @@ dewarpWriteMem(l_uint8  **pdata,
 l_int32  ret;
 FILE    *fp;
 
-    PROCNAME("dewarpWriteMem");
-
     if (pdata) *pdata = NULL;
     if (psize) *psize = 0;
     if (!pdata)
-        return ERROR_INT("&data not defined", procName, 1);
+        return ERROR_INT("&data not defined", __func__, 1);
     if (!psize)
-        return ERROR_INT("&size not defined", procName, 1);
+        return ERROR_INT("&size not defined", __func__, 1);
     if (!dew)
-        return ERROR_INT("dew not defined", procName, 1);
+        return ERROR_INT("dew not defined", __func__, 1);
 
 #if HAVE_FMEMOPEN
     if ((fp = open_memstream((char **)pdata, psize)) == NULL)
-        return ERROR_INT("stream not opened", procName, 1);
+        return ERROR_INT("stream not opened", __func__, 1);
     ret = dewarpWriteStream(fp, dew);
     fputc('\0', fp);
     fclose(fp);
-    *psize = *psize - 1;
+    if (*psize > 0) *psize = *psize - 1;
 #else
-    L_INFO("work-around: writing to a temp file\n", procName);
+    L_INFO("no fmemopen API --> work-around: write to temp file\n", __func__);
   #ifdef _WIN32
     if ((fp = fopenWriteWinTempfile()) == NULL)
-        return ERROR_INT("tmpfile stream not opened", procName, 1);
+        return ERROR_INT("tmpfile stream not opened", __func__, 1);
   #else
     if ((fp = tmpfile()) == NULL)
-        return ERROR_INT("tmpfile stream not opened", procName, 1);
+        return ERROR_INT("tmpfile stream not opened", __func__, 1);
   #endif  /* _WIN32 */
     ret = dewarpWriteStream(fp, dew);
     rewind(fp);
@@ -1455,16 +1419,16 @@ dewarpaRead(const char  *filename)
 FILE       *fp;
 L_DEWARPA  *dewa;
 
-    PROCNAME("dewarpaRead");
-
     if (!filename)
-        return (L_DEWARPA *)ERROR_PTR("filename not defined", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("filename not defined", __func__, NULL);
     if ((fp = fopenReadStream(filename)) == NULL)
-        return (L_DEWARPA *)ERROR_PTR("stream not opened", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR_1("stream not opened",
+                                        filename, __func__, NULL);
 
     if ((dewa = dewarpaReadStream(fp)) == NULL) {
         fclose(fp);
-        return (L_DEWARPA *)ERROR_PTR("dewa not read", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR_1("dewa not read",
+                                        filename, __func__, NULL);
     }
 
     fclose(fp);
@@ -1497,36 +1461,34 @@ L_DEWARP   *dew;
 L_DEWARPA  *dewa;
 NUMA       *namodels;
 
-    PROCNAME("dewarpaReadStream");
-
     if (!fp)
-        return (L_DEWARPA *)ERROR_PTR("stream not defined", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("stream not defined", __func__, NULL);
 
     if (fscanf(fp, "\nDewarpa Version %d\n", &version) != 1)
-        return (L_DEWARPA *)ERROR_PTR("not a dewarpa file", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("not a dewarpa file", __func__, NULL);
     if (version != DEWARP_VERSION_NUMBER)
-        return (L_DEWARPA *)ERROR_PTR("invalid dewarp version", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("invalid dewarp version", __func__, NULL);
 
     if (fscanf(fp, "ndewarp = %d, maxpage = %d\n", &ndewarp, &maxpage) != 2)
-        return (L_DEWARPA *)ERROR_PTR("read fail for maxpage+", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("read fail for maxpage+", __func__, NULL);
     if (ndewarp < 1)
-        return (L_DEWARPA *)ERROR_PTR("pages not >= 1", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("pages not >= 1", __func__, NULL);
     if (ndewarp > MaxPtrArraySize)
-        return (L_DEWARPA *)ERROR_PTR("too many pages", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("too many pages", __func__, NULL);
     if (fscanf(fp,
                "sampling = %d, redfactor = %d, minlines = %d, maxdist = %d\n",
                &sampling, &redfactor, &minlines, &maxdist) != 4)
-        return (L_DEWARPA *)ERROR_PTR("read fail for 4 params", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("read fail for 4 params", __func__, NULL);
     if (fscanf(fp,
           "max_linecurv = %d, min_diff_linecurv = %d, max_diff_linecurv = %d\n",
           &max_linecurv, &min_diff_linecurv, &max_diff_linecurv) != 3)
-        return (L_DEWARPA *)ERROR_PTR("read fail for linecurv", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("read fail for linecurv", __func__, NULL);
     if (fscanf(fp,
               "max_edgeslope = %d, max_edgecurv = %d, max_diff_edgecurv = %d\n",
                &max_edgeslope, &max_edgecurv, &max_diff_edgecurv) != 3)
-        return (L_DEWARPA *)ERROR_PTR("read fail for edgecurv", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("read fail for edgecurv", __func__, NULL);
     if (fscanf(fp, "fullmodel = %d\n", &useboth) != 1)
-        return (L_DEWARPA *)ERROR_PTR("read fail for useboth", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("read fail for useboth", __func__, NULL);
 
     dewa = dewarpaCreate(maxpage + 1, sampling, redfactor, minlines, maxdist);
     dewa->maxpage = maxpage;
@@ -1541,7 +1503,7 @@ NUMA       *namodels;
     dewa->namodels = namodels;
     for (i = 0; i < ndewarp; i++) {
         if ((dew = dewarpReadStream(fp)) == NULL) {
-            L_ERROR("read fail for dew[%d]\n", procName, i);
+            L_ERROR("read fail for dew[%d]\n", __func__, i);
             dewarpaDestroy(&dewa);
             return NULL;
         }
@@ -1569,16 +1531,14 @@ dewarpaReadMem(const l_uint8  *data,
 FILE       *fp;
 L_DEWARPA  *dewa;
 
-    PROCNAME("dewarpaReadMem");
-
     if (!data)
-        return (L_DEWARPA *)ERROR_PTR("data not defined", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("data not defined", __func__, NULL);
     if ((fp = fopenReadFromMemory(data, size)) == NULL)
-        return (L_DEWARPA *)ERROR_PTR("stream not opened", procName, NULL);
+        return (L_DEWARPA *)ERROR_PTR("stream not opened", __func__, NULL);
 
     dewa = dewarpaReadStream(fp);
     fclose(fp);
-    if (!dewa) L_ERROR("dewa not read\n", procName);
+    if (!dewa) L_ERROR("dewa not read\n", __func__);
     return dewa;
 }
 
@@ -1597,19 +1557,17 @@ dewarpaWrite(const char  *filename,
 l_int32  ret;
 FILE    *fp;
 
-    PROCNAME("dewarpaWrite");
-
     if (!filename)
-        return ERROR_INT("filename not defined", procName, 1);
+        return ERROR_INT("filename not defined", __func__, 1);
     if (!dewa)
-        return ERROR_INT("dewa not defined", procName, 1);
+        return ERROR_INT("dewa not defined", __func__, 1);
 
     if ((fp = fopenWriteStream(filename, "wb")) == NULL)
-        return ERROR_INT("stream not opened", procName, 1);
+        return ERROR_INT_1("stream not opened", filename, __func__, 1);
     ret = dewarpaWriteStream(fp, dewa);
     fclose(fp);
     if (ret)
-        return ERROR_INT("dewa not written to stream", procName, 1);
+        return ERROR_INT_1("dewa not written to stream", filename, __func__, 1);
     return 0;
 }
 
@@ -1627,12 +1585,10 @@ dewarpaWriteStream(FILE       *fp,
 {
 l_int32  ndewarp, i, pageno;
 
-    PROCNAME("dewarpaWriteStream");
-
     if (!fp)
-        return ERROR_INT("stream not defined", procName, 1);
+        return ERROR_INT("stream not defined", __func__, 1);
     if (!dewa)
-        return ERROR_INT("dewa not defined", procName, 1);
+        return ERROR_INT("dewa not defined", __func__, 1);
 
         /* Generate the list of page numbers for which a model exists.
          * Note that no attempt is made to determine if the model is
@@ -1641,7 +1597,7 @@ l_int32  ndewarp, i, pageno;
          * can happen later, after all the models have been built. */
     dewarpaListPages(dewa);
     if (!dewa->namodels)
-        return ERROR_INT("dewa->namodels not made", procName, 1);
+        return ERROR_INT("dewa->namodels not made", __func__, 1);
     ndewarp = numaGetCount(dewa->namodels);  /*  with actual page models */
 
     fprintf(fp, "\nDewarpa Version %d\n", DEWARP_VERSION_NUMBER);
@@ -1685,32 +1641,30 @@ dewarpaWriteMem(l_uint8   **pdata,
 l_int32  ret;
 FILE    *fp;
 
-    PROCNAME("dewarpaWriteMem");
-
     if (pdata) *pdata = NULL;
     if (psize) *psize = 0;
     if (!pdata)
-        return ERROR_INT("&data not defined", procName, 1);
+        return ERROR_INT("&data not defined", __func__, 1);
     if (!psize)
-        return ERROR_INT("&size not defined", procName, 1);
+        return ERROR_INT("&size not defined", __func__, 1);
     if (!dewa)
-        return ERROR_INT("dewa not defined", procName, 1);
+        return ERROR_INT("dewa not defined", __func__, 1);
 
 #if HAVE_FMEMOPEN
     if ((fp = open_memstream((char **)pdata, psize)) == NULL)
-        return ERROR_INT("stream not opened", procName, 1);
+        return ERROR_INT("stream not opened", __func__, 1);
     ret = dewarpaWriteStream(fp, dewa);
     fputc('\0', fp);
     fclose(fp);
-    *psize = *psize - 1;
+    if (*psize > 0) *psize = *psize - 1;
 #else
-    L_INFO("work-around: writing to a temp file\n", procName);
+    L_INFO("no fmemopen API --> work-around: write to temp file\n", __func__);
   #ifdef _WIN32
     if ((fp = fopenWriteWinTempfile()) == NULL)
-        return ERROR_INT("tmpfile stream not opened", procName, 1);
+        return ERROR_INT("tmpfile stream not opened", __func__, 1);
   #else
     if ((fp = tmpfile()) == NULL)
-        return ERROR_INT("tmpfile stream not opened", procName, 1);
+        return ERROR_INT("tmpfile stream not opened", __func__, 1);
   #endif  /* _WIN32 */
     ret = dewarpaWriteStream(fp, dewa);
     rewind(fp);
