@@ -217,10 +217,8 @@ pixDilate(PIX  *pixd,
 l_int32  i, j, w, h, sx, sy, cx, cy, seldata;
 PIX     *pixt;
 
-    PROCNAME("pixDilate");
-
     if ((pixd = processMorphArgs1(pixd, pixs, sel, &pixt)) == NULL)
-        return (PIX *)ERROR_PTR("processMorphArgs1 failed", procName, pixd);
+        return (PIX *)ERROR_PTR("processMorphArgs1 failed", __func__, pixd);
 
     pixGetDimensions(pixs, &w, &h, NULL);
     selGetParameters(sel, &sy, &sx, &cy, &cx);
@@ -272,10 +270,8 @@ l_int32  i, j, w, h, sx, sy, cx, cy, seldata;
 l_int32  xp, yp, xn, yn;
 PIX     *pixt;
 
-    PROCNAME("pixErode");
-
     if ((pixd = processMorphArgs1(pixd, pixs, sel, &pixt)) == NULL)
-        return (PIX *)ERROR_PTR("processMorphArgs1 failed", procName, pixd);
+        return (PIX *)ERROR_PTR("processMorphArgs1 failed", __func__, pixd);
 
     pixGetDimensions(pixs, &w, &h, NULL);
     selGetParameters(sel, &sy, &sx, &cy, &cx);
@@ -347,10 +343,8 @@ l_int32  i, j, w, h, sx, sy, cx, cy, firstrasterop, seldata;
 l_int32  xp, yp, xn, yn;
 PIX     *pixt;
 
-    PROCNAME("pixHMT");
-
     if ((pixd = processMorphArgs1(pixd, pixs, sel, &pixt)) == NULL)
-        return (PIX *)ERROR_PTR("processMorphArgs1 failed", procName, pixd);
+        return (PIX *)ERROR_PTR("processMorphArgs1 failed", __func__, pixd);
 
     pixGetDimensions(pixs, &w, &h, NULL);
     selGetParameters(sel, &sy, &sx, &cy, &cx);
@@ -429,13 +423,11 @@ pixOpen(PIX  *pixd,
 {
 PIX  *pixt;
 
-    PROCNAME("pixOpen");
-
     if ((pixd = processMorphArgs2(pixd, pixs, sel)) == NULL)
-        return (PIX *)ERROR_PTR("pixd not returned", procName, pixd);
+        return (PIX *)ERROR_PTR("pixd not returned", __func__, pixd);
 
     if ((pixt = pixErode(NULL, pixs, sel)) == NULL)
-        return (PIX *)ERROR_PTR("pixt not made", procName, pixd);
+        return (PIX *)ERROR_PTR("pixt not made", __func__, pixd);
     pixDilate(pixd, pixt, sel);
     pixDestroy(&pixt);
 
@@ -476,13 +468,11 @@ pixClose(PIX  *pixd,
 {
 PIX  *pixt;
 
-    PROCNAME("pixClose");
-
     if ((pixd = processMorphArgs2(pixd, pixs, sel)) == NULL)
-        return (PIX *)ERROR_PTR("pixd not returned", procName, pixd);
+        return (PIX *)ERROR_PTR("pixd not returned", __func__, pixd);
 
     if ((pixt = pixDilate(NULL, pixs, sel)) == NULL)
-        return (PIX *)ERROR_PTR("pixt not made", procName, pixd);
+        return (PIX *)ERROR_PTR("pixt not made", __func__, pixd);
     pixErode(pixd, pixt, sel);
     pixDestroy(&pixt);
 
@@ -528,14 +518,12 @@ pixCloseSafe(PIX  *pixd,
 l_int32  xp, yp, xn, yn, xmax, xbord;
 PIX     *pixt1, *pixt2;
 
-    PROCNAME("pixCloseSafe");
-
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, pixd);
     if (!sel)
-        return (PIX *)ERROR_PTR("sel not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("sel not defined", __func__, pixd);
     if (pixGetDepth(pixs) != 1)
-        return (PIX *)ERROR_PTR("pixs not 1 bpp", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not 1 bpp", __func__, pixd);
 
         /* Symmetric b.c. handles correctly without added pixels */
     if (MORPH_BC == SYMMETRIC_MORPH_BC)
@@ -546,10 +534,10 @@ PIX     *pixt1, *pixt2;
     xbord = 32 * ((xmax + 31) / 32);  /* full 32 bit words */
 
     if ((pixt1 = pixAddBorderGeneral(pixs, xbord, xbord, yp, yn, 0)) == NULL)
-        return (PIX *)ERROR_PTR("pixt1 not made", procName, pixd);
+        return (PIX *)ERROR_PTR("pixt1 not made", __func__, pixd);
     pixClose(pixt1, pixt1, sel);
     if ((pixt2 = pixRemoveBorderGeneral(pixt1, xbord, xbord, yp, yn)) == NULL)
-        return (PIX *)ERROR_PTR("pixt2 not made", procName, pixd);
+        return (PIX *)ERROR_PTR("pixt2 not made", __func__, pixd);
     pixDestroy(&pixt1);
 
     if (!pixd)
@@ -594,13 +582,11 @@ pixOpenGeneralized(PIX  *pixd,
 {
 PIX  *pixt;
 
-    PROCNAME("pixOpenGeneralized");
-
     if ((pixd = processMorphArgs2(pixd, pixs, sel)) == NULL)
-        return (PIX *)ERROR_PTR("pixd not returned", procName, pixd);
+        return (PIX *)ERROR_PTR("pixd not returned", __func__, pixd);
 
     if ((pixt = pixHMT(NULL, pixs, sel)) == NULL)
-        return (PIX *)ERROR_PTR("pixt not made", procName, pixd);
+        return (PIX *)ERROR_PTR("pixt not made", __func__, pixd);
     pixDilate(pixd, pixt, sel);
     pixDestroy(&pixt);
     return pixd;
@@ -641,13 +627,11 @@ pixCloseGeneralized(PIX  *pixd,
 {
 PIX  *pixt;
 
-    PROCNAME("pixCloseGeneralized");
-
     if ((pixd = processMorphArgs2(pixd, pixs, sel)) == NULL)
-        return (PIX *)ERROR_PTR("pixd not returned", procName, pixd);
+        return (PIX *)ERROR_PTR("pixd not returned", __func__, pixd);
 
     if ((pixt = pixDilate(NULL, pixs, sel)) == NULL)
-        return (PIX *)ERROR_PTR("pixt not made", procName, pixd);
+        return (PIX *)ERROR_PTR("pixt not made", __func__, pixd);
     pixHMT(pixd, pixt, sel);
     pixDestroy(&pixt);
 
@@ -693,29 +677,27 @@ pixDilateBrick(PIX     *pixd,
 PIX  *pixt;
 SEL  *sel, *selh, *selv;
 
-    PROCNAME("pixDilateBrick");
-
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, pixd);
     if (pixGetDepth(pixs) != 1)
-        return (PIX *)ERROR_PTR("pixs not 1 bpp", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not 1 bpp", __func__, pixd);
     if (hsize < 1 || vsize < 1)
-        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", procName, pixd);
+        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", __func__, pixd);
 
     if (hsize == 1 && vsize == 1)
         return pixCopy(pixd, pixs);
     if (hsize == 1 || vsize == 1) {  /* no intermediate result */
         sel = selCreateBrick(vsize, hsize, vsize / 2, hsize / 2, SEL_HIT);
         if (!sel)
-            return (PIX *)ERROR_PTR("sel not made", procName, pixd);
+            return (PIX *)ERROR_PTR("sel not made", __func__, pixd);
         pixd = pixDilate(pixd, pixs, sel);
         selDestroy(&sel);
     } else {
         if ((selh = selCreateBrick(1, hsize, 0, hsize / 2, SEL_HIT)) == NULL)
-            return (PIX *)ERROR_PTR("selh not made", procName, pixd);
+            return (PIX *)ERROR_PTR("selh not made", __func__, pixd);
         if ((selv = selCreateBrick(vsize, 1, vsize / 2, 0, SEL_HIT)) == NULL) {
             selDestroy(&selh);
-            return (PIX *)ERROR_PTR("selv not made", procName, pixd);
+            return (PIX *)ERROR_PTR("selv not made", __func__, pixd);
         }
         pixt = pixDilate(NULL, pixs, selh);
         pixd = pixDilate(pixd, pixt, selv);
@@ -763,29 +745,27 @@ pixErodeBrick(PIX     *pixd,
 PIX  *pixt;
 SEL  *sel, *selh, *selv;
 
-    PROCNAME("pixErodeBrick");
-
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, pixd);
     if (pixGetDepth(pixs) != 1)
-        return (PIX *)ERROR_PTR("pixs not 1 bpp", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not 1 bpp", __func__, pixd);
     if (hsize < 1 || vsize < 1)
-        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", procName, pixd);
+        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", __func__, pixd);
 
     if (hsize == 1 && vsize == 1)
         return pixCopy(pixd, pixs);
     if (hsize == 1 || vsize == 1) {  /* no intermediate result */
         sel = selCreateBrick(vsize, hsize, vsize / 2, hsize / 2, SEL_HIT);
         if (!sel)
-            return (PIX *)ERROR_PTR("sel not made", procName, pixd);
+            return (PIX *)ERROR_PTR("sel not made", __func__, pixd);
         pixd = pixErode(pixd, pixs, sel);
         selDestroy(&sel);
     } else {
         if ((selh = selCreateBrick(1, hsize, 0, hsize / 2, SEL_HIT)) == NULL)
-            return (PIX *)ERROR_PTR("selh not made", procName, pixd);
+            return (PIX *)ERROR_PTR("selh not made", __func__, pixd);
         if ((selv = selCreateBrick(vsize, 1, vsize / 2, 0, SEL_HIT)) == NULL) {
             selDestroy(&selh);
-            return (PIX *)ERROR_PTR("selv not made", procName, pixd);
+            return (PIX *)ERROR_PTR("selv not made", __func__, pixd);
         }
         pixt = pixErode(NULL, pixs, selh);
         pixd = pixErode(pixd, pixt, selv);
@@ -833,29 +813,27 @@ pixOpenBrick(PIX     *pixd,
 PIX  *pixt;
 SEL  *sel, *selh, *selv;
 
-    PROCNAME("pixOpenBrick");
-
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, pixd);
     if (pixGetDepth(pixs) != 1)
-        return (PIX *)ERROR_PTR("pixs not 1 bpp", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not 1 bpp", __func__, pixd);
     if (hsize < 1 || vsize < 1)
-        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", procName, pixd);
+        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", __func__, pixd);
 
     if (hsize == 1 && vsize == 1)
         return pixCopy(pixd, pixs);
     if (hsize == 1 || vsize == 1) {  /* no intermediate result */
         sel = selCreateBrick(vsize, hsize, vsize / 2, hsize / 2, SEL_HIT);
         if (!sel)
-            return (PIX *)ERROR_PTR("sel not made", procName, pixd);
+            return (PIX *)ERROR_PTR("sel not made", __func__, pixd);
         pixd = pixOpen(pixd, pixs, sel);
         selDestroy(&sel);
     } else {  /* do separably */
         if ((selh = selCreateBrick(1, hsize, 0, hsize / 2, SEL_HIT)) == NULL)
-            return (PIX *)ERROR_PTR("selh not made", procName, pixd);
+            return (PIX *)ERROR_PTR("selh not made", __func__, pixd);
         if ((selv = selCreateBrick(vsize, 1, vsize / 2, 0, SEL_HIT)) == NULL) {
             selDestroy(&selh);
-            return (PIX *)ERROR_PTR("selv not made", procName, pixd);
+            return (PIX *)ERROR_PTR("selv not made", __func__, pixd);
         }
         pixt = pixErode(NULL, pixs, selh);
         pixd = pixErode(pixd, pixt, selv);
@@ -905,29 +883,27 @@ pixCloseBrick(PIX     *pixd,
 PIX  *pixt;
 SEL  *sel, *selh, *selv;
 
-    PROCNAME("pixCloseBrick");
-
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, pixd);
     if (pixGetDepth(pixs) != 1)
-        return (PIX *)ERROR_PTR("pixs not 1 bpp", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not 1 bpp", __func__, pixd);
     if (hsize < 1 || vsize < 1)
-        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", procName, pixd);
+        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", __func__, pixd);
 
     if (hsize == 1 && vsize == 1)
         return pixCopy(pixd, pixs);
     if (hsize == 1 || vsize == 1) {  /* no intermediate result */
         sel = selCreateBrick(vsize, hsize, vsize / 2, hsize / 2, SEL_HIT);
         if (!sel)
-            return (PIX *)ERROR_PTR("sel not made", procName, pixd);
+            return (PIX *)ERROR_PTR("sel not made", __func__, pixd);
         pixd = pixClose(pixd, pixs, sel);
         selDestroy(&sel);
     } else {  /* do separably */
         if ((selh = selCreateBrick(1, hsize, 0, hsize / 2, SEL_HIT)) == NULL)
-            return (PIX *)ERROR_PTR("selh not made", procName, pixd);
+            return (PIX *)ERROR_PTR("selh not made", __func__, pixd);
         if ((selv = selCreateBrick(vsize, 1, vsize / 2, 0, SEL_HIT)) == NULL) {
             selDestroy(&selh);
-            return (PIX *)ERROR_PTR("selv not made", procName, pixd);
+            return (PIX *)ERROR_PTR("selv not made", __func__, pixd);
         }
         pixt = pixDilate(NULL, pixs, selh);
         pixd = pixDilate(pixd, pixt, selv);
@@ -983,14 +959,12 @@ l_int32  maxtrans, bordsize;
 PIX     *pixsb, *pixt, *pixdb;
 SEL     *sel, *selh, *selv;
 
-    PROCNAME("pixCloseSafeBrick");
-
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, pixd);
     if (pixGetDepth(pixs) != 1)
-        return (PIX *)ERROR_PTR("pixs not 1 bpp", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not 1 bpp", __func__, pixd);
     if (hsize < 1 || vsize < 1)
-        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", procName, pixd);
+        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", __func__, pixd);
 
     if (hsize == 1 && vsize == 1)
         return pixCopy(pixd, pixs);
@@ -1007,7 +981,7 @@ SEL     *sel, *selh, *selv;
         sel = selCreateBrick(vsize, hsize, vsize / 2, hsize / 2, SEL_HIT);
         if (!sel) {
             pixDestroy(&pixsb);
-            return (PIX *)ERROR_PTR("sel not made", procName, pixd);
+            return (PIX *)ERROR_PTR("sel not made", __func__, pixd);
         }
         pixdb = pixClose(NULL, pixsb, sel);
         selDestroy(&sel);
@@ -1016,10 +990,10 @@ SEL     *sel, *selh, *selv;
         selv = selCreateBrick(vsize, 1, vsize / 2, 0, SEL_HIT);
         if (!selh || !selv) {
             selDestroy(&selh);
-            selDestroy(&selh);
+            selDestroy(&selv);
             pixDestroy(&pixsb);
             return (PIX *)ERROR_PTR("selh and selv not both made",
-                                    procName, pixd);
+                                    __func__, pixd);
         }
         pixt = pixDilate(NULL, pixsb, selh);
         pixdb = pixDilate(NULL, pixt, selv);
@@ -1081,19 +1055,17 @@ selectComposableSels(l_int32  size,
 {
 l_int32  factor1, factor2;
 
-    PROCNAME("selectComposableSels");
-
     if (!psel1 && !psel2)
-        return ERROR_INT("neither &sel1 nor &sel2 are defined", procName, 1);
+        return ERROR_INT("neither &sel1 nor &sel2 are defined", __func__, 1);
     if (psel1) *psel1 = NULL;
     if (psel2) *psel2 = NULL;
     if (size < 1 || size > 10000)
-        return ERROR_INT("size < 1 or size > 10000", procName, 1);
+        return ERROR_INT("size < 1 or size > 10000", __func__, 1);
     if (direction != L_HORIZ && direction != L_VERT)
-        return ERROR_INT("invalid direction", procName, 1);
+        return ERROR_INT("invalid direction", __func__, 1);
 
     if (selectComposableSizes(size, &factor1, &factor2))
-        return ERROR_INT("factors not found", procName, 1);
+        return ERROR_INT("factors not found", __func__, 1);
 
     if (psel1) {
         if (direction == L_HORIZ)
@@ -1141,12 +1113,10 @@ l_int32  hival[256];
 l_int32  rastcost[256];  /* excess in sum of sizes (extra rasterops) */
 l_int32  diff[256];  /* diff between product (sel size) and input size */
 
-    PROCNAME("selectComposableSizes");
-
     if (size < 1 || size > 10000)
-        return ERROR_INT("size < 1 or size > 10000", procName, 1);
+        return ERROR_INT("size < 1 or size > 10000", __func__, 1);
     if (!pfactor1 || !pfactor2)
-        return ERROR_INT("&factor1 or &factor2 not defined", procName, 1);
+        return ERROR_INT("&factor1 or &factor2 not defined", __func__, 1);
 
     midval = (l_int32)(sqrt((l_float64)size) + 0.001);
     if (midval * midval == size) {
@@ -1252,14 +1222,12 @@ SEL  *selh2 = NULL;
 SEL  *selv1 = NULL;
 SEL  *selv2 = NULL;
 
-    PROCNAME("pixDilateCompBrick");
-
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, pixd);
     if (pixGetDepth(pixs) != 1)
-        return (PIX *)ERROR_PTR("pixs not 1 bpp", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not 1 bpp", __func__, pixd);
     if (hsize < 1 || vsize < 1)
-        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", procName, pixd);
+        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", __func__, pixd);
 
     if (hsize == 1 && vsize == 1)
         return pixCopy(pixd, pixs);
@@ -1267,7 +1235,7 @@ SEL  *selv2 = NULL;
         if (selectComposableSels(hsize, L_HORIZ, &selh1, &selh2)) {
             selDestroy(&selh1);
             selDestroy(&selh2);
-            return (PIX *)ERROR_PTR("horiz sels not made", procName, pixd);
+            return (PIX *)ERROR_PTR("horiz sels not made", __func__, pixd);
         }
     }
     if (vsize > 1) {
@@ -1276,7 +1244,7 @@ SEL  *selv2 = NULL;
             selDestroy(&selh2);
             selDestroy(&selv1);
             selDestroy(&selv2);
-            return (PIX *)ERROR_PTR("vert sels not made", procName, pixd);
+            return (PIX *)ERROR_PTR("vert sels not made", __func__, pixd);
         }
     }
 
@@ -1363,14 +1331,12 @@ SEL  *selh2 = NULL;
 SEL  *selv1 = NULL;
 SEL  *selv2 = NULL;
 
-    PROCNAME("pixErodeCompBrick");
-
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, pixd);
     if (pixGetDepth(pixs) != 1)
-        return (PIX *)ERROR_PTR("pixs not 1 bpp", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not 1 bpp", __func__, pixd);
     if (hsize < 1 || vsize < 1)
-        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", procName, pixd);
+        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", __func__, pixd);
 
     if (hsize == 1 && vsize == 1)
         return pixCopy(pixd, pixs);
@@ -1378,7 +1344,7 @@ SEL  *selv2 = NULL;
         if (selectComposableSels(hsize, L_HORIZ, &selh1, &selh2)) {
             selDestroy(&selh1);
             selDestroy(&selh2);
-            return (PIX *)ERROR_PTR("horiz sels not made", procName, pixd);
+            return (PIX *)ERROR_PTR("horiz sels not made", __func__, pixd);
         }
     }
     if (vsize > 1) {
@@ -1387,7 +1353,7 @@ SEL  *selv2 = NULL;
             selDestroy(&selh2);
             selDestroy(&selv1);
             selDestroy(&selv2);
-            return (PIX *)ERROR_PTR("vert sels not made", procName, pixd);
+            return (PIX *)ERROR_PTR("vert sels not made", __func__, pixd);
         }
     }
 
@@ -1465,14 +1431,12 @@ SEL  *selh2 = NULL;
 SEL  *selv1 = NULL;
 SEL  *selv2 = NULL;
 
-    PROCNAME("pixOpenCompBrick");
-
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, pixd);
     if (pixGetDepth(pixs) != 1)
-        return (PIX *)ERROR_PTR("pixs not 1 bpp", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not 1 bpp", __func__, pixd);
     if (hsize < 1 || vsize < 1)
-        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", procName, pixd);
+        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", __func__, pixd);
 
     if (hsize == 1 && vsize == 1)
         return pixCopy(pixd, pixs);
@@ -1480,7 +1444,7 @@ SEL  *selv2 = NULL;
         if (selectComposableSels(hsize, L_HORIZ, &selh1, &selh2)) {
             selDestroy(&selh1);
             selDestroy(&selh2);
-            return (PIX *)ERROR_PTR("horiz sels not made", procName, pixd);
+            return (PIX *)ERROR_PTR("horiz sels not made", __func__, pixd);
         }
     }
     if (vsize > 1) {
@@ -1489,7 +1453,7 @@ SEL  *selv2 = NULL;
             selDestroy(&selh2);
             selDestroy(&selv1);
             selDestroy(&selv2);
-            return (PIX *)ERROR_PTR("vert sels not made", procName, pixd);
+            return (PIX *)ERROR_PTR("vert sels not made", __func__, pixd);
         }
     }
 
@@ -1575,14 +1539,12 @@ SEL  *selh2 = NULL;
 SEL  *selv1 = NULL;
 SEL  *selv2 = NULL;
 
-    PROCNAME("pixCloseCompBrick");
-
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, pixd);
     if (pixGetDepth(pixs) != 1)
-        return (PIX *)ERROR_PTR("pixs not 1 bpp", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not 1 bpp", __func__, pixd);
     if (hsize < 1 || vsize < 1)
-        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", procName, pixd);
+        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", __func__, pixd);
 
     if (hsize == 1 && vsize == 1)
         return pixCopy(pixd, pixs);
@@ -1590,7 +1552,7 @@ SEL  *selv2 = NULL;
         if (selectComposableSels(hsize, L_HORIZ, &selh1, &selh2)) {
             selDestroy(&selh1);
             selDestroy(&selh2);
-            return (PIX *)ERROR_PTR("horiz sels not made", procName, pixd);
+            return (PIX *)ERROR_PTR("horiz sels not made", __func__, pixd);
         }
     }
     if (vsize > 1) {
@@ -1599,7 +1561,7 @@ SEL  *selv2 = NULL;
             selDestroy(&selh2);
             selDestroy(&selv1);
             selDestroy(&selv2);
-            return (PIX *)ERROR_PTR("vert sels not made", procName, pixd);
+            return (PIX *)ERROR_PTR("vert sels not made", __func__, pixd);
         }
     }
 
@@ -1691,14 +1653,12 @@ SEL     *selh2 = NULL;
 SEL     *selv1 = NULL;
 SEL     *selv2 = NULL;
 
-    PROCNAME("pixCloseSafeCompBrick");
-
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, pixd);
     if (pixGetDepth(pixs) != 1)
-        return (PIX *)ERROR_PTR("pixs not 1 bpp", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not 1 bpp", __func__, pixd);
     if (hsize < 1 || vsize < 1)
-        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", procName, pixd);
+        return (PIX *)ERROR_PTR("hsize and vsize not >= 1", __func__, pixd);
 
     if (hsize == 1 && vsize == 1)
         return pixCopy(pixd, pixs);
@@ -1711,7 +1671,7 @@ SEL     *selv2 = NULL;
         if (selectComposableSels(hsize, L_HORIZ, &selh1, &selh2)) {
             selDestroy(&selh1);
             selDestroy(&selh2);
-            return (PIX *)ERROR_PTR("horiz sels not made", procName, pixd);
+            return (PIX *)ERROR_PTR("horiz sels not made", __func__, pixd);
         }
     }
     if (vsize > 1) {
@@ -1720,7 +1680,7 @@ SEL     *selv2 = NULL;
             selDestroy(&selh2);
             selDestroy(&selv1);
             selDestroy(&selv2);
-            return (PIX *)ERROR_PTR("vert sels not made", procName, pixd);
+            return (PIX *)ERROR_PTR("vert sels not made", __func__, pixd);
         }
     }
 
@@ -1781,10 +1741,8 @@ SEL     *selv2 = NULL;
 void
 resetMorphBoundaryCondition(l_int32  bc)
 {
-    PROCNAME("resetMorphBoundaryCondition");
-
     if (bc != SYMMETRIC_MORPH_BC && bc != ASYMMETRIC_MORPH_BC) {
-        L_WARNING("invalid bc; using asymmetric\n", procName);
+        L_WARNING("invalid bc; using asymmetric\n", __func__);
         bc = ASYMMETRIC_MORPH_BC;
     }
     MORPH_BC = bc;
@@ -1803,13 +1761,11 @@ l_uint32
 getMorphBorderPixelColor(l_int32  type,
                          l_int32  depth)
 {
-    PROCNAME("getMorphBorderPixelColor");
-
     if (type != L_MORPH_DILATE && type != L_MORPH_ERODE)
-        return ERROR_INT("invalid type", procName, 0);
+        return ERROR_INT("invalid type", __func__, 0);
     if (depth != 1 && depth != 2 && depth != 4 && depth != 8 &&
         depth != 16 && depth != 32)
-        return ERROR_INT("invalid depth", procName, 0);
+        return ERROR_INT("invalid depth", __func__, 0);
 
     if (MORPH_BC == ASYMMETRIC_MORPH_BC || type == L_MORPH_DILATE)
         return 0;
@@ -1848,33 +1804,31 @@ processMorphArgs1(PIX   *pixd,
 {
 l_int32  sx, sy;
 
-    PROCNAME("processMorphArgs1");
-
     if (!ppixt)
-        return (PIX *)ERROR_PTR("&pixt not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("&pixt not defined", __func__, pixd);
     *ppixt = NULL;
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, pixd);
     if (!sel)
-        return (PIX *)ERROR_PTR("sel not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("sel not defined", __func__, pixd);
     if (pixGetDepth(pixs) != 1)
-        return (PIX *)ERROR_PTR("pixs not 1 bpp", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not 1 bpp", __func__, pixd);
 
     selGetParameters(sel, &sx, &sy, NULL, NULL);
     if (sx == 0 || sy == 0)
-        return (PIX *)ERROR_PTR("sel of size 0", procName, pixd);
+        return (PIX *)ERROR_PTR("sel of size 0", __func__, pixd);
 
         /* We require pixd to exist and to be the same size as pixs.
          * Further, pixt must be a copy (or clone) of pixs.  */
     if (!pixd) {
         if ((pixd = pixCreateTemplate(pixs)) == NULL)
-            return (PIX *)ERROR_PTR("pixd not made", procName, NULL);
+            return (PIX *)ERROR_PTR("pixd not made", __func__, NULL);
         *ppixt = pixClone(pixs);
     } else {
         pixResizeImageData(pixd, pixs);
         if (pixd == pixs) {  /* in-place; must make a copy of pixs */
             if ((*ppixt = pixCopy(NULL, pixs)) == NULL)
-                return (PIX *)ERROR_PTR("pixt not made", procName, pixd);
+                return (PIX *)ERROR_PTR("pixt not made", __func__, pixd);
         } else {
             *ppixt = pixClone(pixs);
         }
@@ -1895,18 +1849,16 @@ processMorphArgs2(PIX   *pixd,
 {
 l_int32  sx, sy;
 
-    PROCNAME("processMorphArgs2");
-
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, pixd);
     if (!sel)
-        return (PIX *)ERROR_PTR("sel not defined", procName, pixd);
+        return (PIX *)ERROR_PTR("sel not defined", __func__, pixd);
     if (pixGetDepth(pixs) != 1)
-        return (PIX *)ERROR_PTR("pixs not 1 bpp", procName, pixd);
+        return (PIX *)ERROR_PTR("pixs not 1 bpp", __func__, pixd);
 
     selGetParameters(sel, &sx, &sy, NULL, NULL);
     if (sx == 0 || sy == 0)
-        return (PIX *)ERROR_PTR("sel of size 0", procName, pixd);
+        return (PIX *)ERROR_PTR("sel of size 0", __func__, pixd);
 
     if (!pixd)
         return pixCreateTemplate(pixs);
