@@ -110,14 +110,14 @@ static const l_float32  DefaultSweepDelta = 1.0;   /* degrees */
      * search in pixFindSkew().  The expected accuracy is
      * not better than the inverse image width in pixels,
      * say, 1/2000 radians, or about 0.03 degrees. */
-static const l_float32  DefaultMinbsDelta = 0.01;  /* degrees */
+static const l_float32  DefaultMinbsDelta = 0.01f;  /* degrees */
 
     /* Default scale factors for pixFindSkew() */
 static const l_int32  DefaultSweepReduction = 4;  /* sweep part; 4 is good */
 static const l_int32  DefaultBsReduction = 2;  /* binary search part */
 
     /* Minimum angle for deskewing in pixDeskew() */
-static const l_float32  MinDeskewAngle = 0.1;  /* degree */
+static const l_float32  MinDeskewAngle = 0.1f;  /* degree */
 
     /* Minimum allowed confidence (ratio) for deskewing in pixDeskew() */
 static const l_float32  MinAllowedConfidence = 3.0;
@@ -128,10 +128,12 @@ static const l_int32  MinValidMaxscore = 10000;
     /* Constant setting threshold for minimum allowed minscore
      * to give nonzero confidence; multiply this constant by
      *  (height * width^2) */
-static const l_float32  MinscoreThreshFactor = 0.000002;
+static const l_float32  MinscoreThreshFactor = 0.000002f;
 
-    /* Default binarization threshold value */
-static const l_int32  DefaultBinaryThreshold = 130;
+    /* Default binarization threshold value.
+     * This is set deliberately above 130 to capture light foreground
+     * with poor printing or images that are out of focus.  */
+static const l_int32  DefaultBinaryThreshold = 160;
 
 #ifndef  NO_CONSOLE_IO
 #define  DEBUG_PRINT_SCORES     0
@@ -160,7 +162,6 @@ static const l_int32  DefaultBinaryThreshold = 130;
  *      (1) This binarizes if necessary and does both horizontal
  *          and vertical deskewing, using the default parameters in
  *          the underlying pixDeskew().  See usage there.
- *      (2) This may return a clone.
  * </pre>
  */
 PIX *
@@ -169,14 +170,12 @@ pixDeskewBoth(PIX     *pixs,
 {
 PIX  *pix1, *pix2, *pix3, *pix4;
 
-    PROCNAME("pixDeskewBoth");
-
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, NULL);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, NULL);
     if (redsearch == 0)
         redsearch = DefaultBsReduction;
     else if (redsearch != 1 && redsearch != 2 && redsearch != 4)
-        return (PIX *)ERROR_PTR("redsearch not in {1,2,4}", procName, NULL);
+        return (PIX *)ERROR_PTR("redsearch not in {1,2,4}", __func__, NULL);
 
     pix1 = pixDeskew(pixs, redsearch);
     pix2 = pixRotate90(pix1, 1);
@@ -210,14 +209,12 @@ PIX *
 pixDeskew(PIX     *pixs,
           l_int32  redsearch)
 {
-    PROCNAME("pixDeskew");
-
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, NULL);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, NULL);
     if (redsearch == 0)
         redsearch = DefaultBsReduction;
     else if (redsearch != 1 && redsearch != 2 && redsearch != 4)
-        return (PIX *)ERROR_PTR("redsearch not in {1,2,4}", procName, NULL);
+        return (PIX *)ERROR_PTR("redsearch not in {1,2,4}", __func__, NULL);
 
     return pixDeskewGeneral(pixs, 0, 0.0, 0.0, redsearch, 0, NULL, NULL);
 }
@@ -248,14 +245,12 @@ pixFindSkewAndDeskew(PIX        *pixs,
                      l_float32  *pangle,
                      l_float32  *pconf)
 {
-    PROCNAME("pixFindSkewAndDeskew");
-
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, NULL);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, NULL);
     if (redsearch == 0)
         redsearch = DefaultBsReduction;
     else if (redsearch != 1 && redsearch != 2 && redsearch != 4)
-        return (PIX *)ERROR_PTR("redsearch not in {1,2,4}", procName, NULL);
+        return (PIX *)ERROR_PTR("redsearch not in {1,2,4}", __func__, NULL);
 
     return pixDeskewGeneral(pixs, 0, 0.0, 0.0, redsearch, 0, pangle, pconf);
 }
@@ -300,16 +295,14 @@ l_int32    ret, depth;
 l_float32  angle, conf, deg2rad;
 PIX       *pixb, *pixd;
 
-    PROCNAME("pixDeskewGeneral");
-
     if (pangle) *pangle = 0.0;
     if (pconf) *pconf = 0.0;
     if (!pixs)
-        return (PIX *)ERROR_PTR("pixs not defined", procName, NULL);
+        return (PIX *)ERROR_PTR("pixs not defined", __func__, NULL);
     if (redsweep == 0)
         redsweep = DefaultSweepReduction;
     else if (redsweep != 1 && redsweep != 2 && redsweep != 4)
-        return (PIX *)ERROR_PTR("redsweep not in {1,2,4}", procName, NULL);
+        return (PIX *)ERROR_PTR("redsweep not in {1,2,4}", __func__, NULL);
     if (sweeprange == 0.0)
         sweeprange = DefaultSweepRange;
     if (sweepdelta == 0.0)
@@ -317,11 +310,11 @@ PIX       *pixb, *pixd;
     if (redsearch == 0)
         redsearch = DefaultBsReduction;
     else if (redsearch != 1 && redsearch != 2 && redsearch != 4)
-        return (PIX *)ERROR_PTR("redsearch not in {1,2,4}", procName, NULL);
+        return (PIX *)ERROR_PTR("redsearch not in {1,2,4}", __func__, NULL);
     if (thresh == 0)
         thresh = DefaultBinaryThreshold;
 
-    deg2rad = 3.1415926535 / 180.;
+    deg2rad = 3.1415926535f / 180.f;
 
         /* Binarize if necessary */
     depth = pixGetDepth(pixs);
@@ -376,16 +369,14 @@ pixFindSkew(PIX        *pixs,
             l_float32  *pangle,
             l_float32  *pconf)
 {
-    PROCNAME("pixFindSkew");
-
     if (pangle) *pangle = 0.0;
     if (pconf) *pconf = 0.0;
     if (!pangle || !pconf)
-        return ERROR_INT("&angle and/or &conf not defined", procName, 1);
+        return ERROR_INT("&angle and/or &conf not defined", __func__, 1);
     if (!pixs)
-        return ERROR_INT("pixs not defined", procName, 1);
+        return ERROR_INT("pixs not defined", __func__, 1);
     if (pixGetDepth(pixs) != 1)
-        return ERROR_INT("pixs not 1 bpp", procName, 1);
+        return ERROR_INT("pixs not 1 bpp", __func__, 1);
 
     return pixFindSkewSweepAndSearch(pixs, pangle, pconf,
                                      DefaultSweepReduction,
@@ -428,19 +419,17 @@ l_float32  sum, maxscore, maxangle;
 NUMA      *natheta, *nascore;
 PIX       *pix, *pixt;
 
-    PROCNAME("pixFindSkewSweep");
-
     if (!pangle)
-        return ERROR_INT("&angle not defined", procName, 1);
+        return ERROR_INT("&angle not defined", __func__, 1);
     *pangle = 0.0;
     if (!pixs)
-        return ERROR_INT("pixs not defined", procName, 1);
+        return ERROR_INT("pixs not defined", __func__, 1);
     if (pixGetDepth(pixs) != 1)
-        return ERROR_INT("pixs not 1 bpp", procName, 1);
+        return ERROR_INT("pixs not 1 bpp", __func__, 1);
     if (reduction != 1 && reduction != 2 && reduction != 4 && reduction != 8)
-        return ERROR_INT("reduction must be in {1,2,4,8}", procName, 1);
+        return ERROR_INT("reduction must be in {1,2,4,8}", __func__, 1);
 
-    deg2rad = 3.1415926535 / 180.;
+    deg2rad = 3.1415926535f / 180.f;
     ret = 0;
 
         /* Generate reduced image, if requested */
@@ -465,11 +454,11 @@ PIX       *pix, *pixt;
     pixt = pixCreateTemplate(pix);
 
     if (!pix || !pixt) {
-        ret = ERROR_INT("pix and pixt not both made", procName, 1);
+        ret = ERROR_INT("pix and pixt not both made", __func__, 1);
         goto cleanup;
     }
     if (!natheta || !nascore) {
-        ret = ERROR_INT("natheta and nascore not both made", procName, 1);
+        ret = ERROR_INT("natheta and nascore not both made", __func__, 1);
         goto cleanup;
     }
 
@@ -483,7 +472,7 @@ PIX       *pix, *pixt;
         pixFindDifferentialSquareSum(pixt, &sum);
 
 #if  DEBUG_PRINT_SCORES
-        L_INFO("sum(%7.2f) = %7.0f\n", procName, theta, sum);
+        L_INFO("sum(%7.2f) = %7.0f\n", __func__, theta, sum);
 #endif  /* DEBUG_PRINT_SCORES */
 
             /* Save the result in the output arrays */
@@ -498,7 +487,7 @@ PIX       *pix, *pixt;
     *pangle = maxangle;
 
 #if  DEBUG_PRINT_SWEEP
-    L_INFO(" From sweep: angle = %7.3f, score = %7.3f\n", procName,
+    L_INFO(" From sweep: angle = %7.3f, score = %7.3f\n", __func__,
            maxangle, maxscore);
 #endif  /* DEBUG_PRINT_SWEEP */
 
@@ -687,25 +676,23 @@ l_float32  rangeleft;
 NUMA      *natheta, *nascore;
 PIX       *pixsw, *pixsch, *pixt1, *pixt2;
 
-    PROCNAME("pixFindSkewSweepAndSearchScorePivot");
-
     if (pendscore) *pendscore = 0.0;
     if (pangle) *pangle = 0.0;
     if (pconf) *pconf = 0.0;
     if (!pangle || !pconf)
-        return ERROR_INT("&angle and/or &conf not defined", procName, 1);
+        return ERROR_INT("&angle and/or &conf not defined", __func__, 1);
     if (!pixs || pixGetDepth(pixs) != 1)
-        return ERROR_INT("pixs not defined or not 1 bpp", procName, 1);
+        return ERROR_INT("pixs not defined or not 1 bpp", __func__, 1);
     if (redsweep != 1 && redsweep != 2 && redsweep != 4 && redsweep != 8)
-        return ERROR_INT("redsweep must be in {1,2,4,8}", procName, 1);
+        return ERROR_INT("redsweep must be in {1,2,4,8}", __func__, 1);
     if (redsearch != 1 && redsearch != 2 && redsearch != 4 && redsearch != 8)
-        return ERROR_INT("redsearch must be in {1,2,4,8}", procName, 1);
+        return ERROR_INT("redsearch must be in {1,2,4,8}", __func__, 1);
     if (redsearch > redsweep)
-        return ERROR_INT("redsearch must not exceed redsweep", procName, 1);
+        return ERROR_INT("redsearch must not exceed redsweep", __func__, 1);
     if (pivot != L_SHEAR_ABOUT_CORNER && pivot != L_SHEAR_ABOUT_CENTER)
-        return ERROR_INT("invalid pivot", procName, 1);
+        return ERROR_INT("invalid pivot", __func__, 1);
 
-    deg2rad = 3.1415926535 / 180.;
+    deg2rad = 3.1415926535f / 180.f;
     ret = 0;
 
         /* Generate reduced image for binary search, if requested */
@@ -748,15 +735,15 @@ PIX       *pixsw, *pixsch, *pixt1, *pixt2;
     nascore = numaCreate(nangles);
 
     if (!pixsch || !pixsw) {
-        ret = ERROR_INT("pixsch and pixsw not both made", procName, 1);
+        ret = ERROR_INT("pixsch and pixsw not both made", __func__, 1);
         goto cleanup;
     }
     if (!pixt1 || !pixt2) {
-        ret = ERROR_INT("pixt1 and pixt2 not both made", procName, 1);
+        ret = ERROR_INT("pixt1 and pixt2 not both made", __func__, 1);
         goto cleanup;
     }
     if (!natheta || !nascore) {
-        ret = ERROR_INT("natheta and nascore not both made", procName, 1);
+        ret = ERROR_INT("natheta and nascore not both made", __func__, 1);
         goto cleanup;
     }
 
@@ -775,7 +762,7 @@ PIX       *pixsw, *pixsch, *pixt1, *pixt2;
         pixFindDifferentialSquareSum(pixt1, &sum);
 
 #if  DEBUG_PRINT_SCORES
-        L_INFO("sum(%7.2f) = %7.0f\n", procName, theta, sum);
+        L_INFO("sum(%7.2f) = %7.0f\n", __func__, theta, sum);
 #endif  /* DEBUG_PRINT_SCORES */
 
             /* Save the result in the output arrays */
@@ -788,7 +775,7 @@ PIX       *pixsw, *pixsch, *pixt1, *pixt2;
     numaGetFValue(natheta, maxindex, &maxangle);
 
 #if  DEBUG_PRINT_SWEEP
-    L_INFO(" From sweep: angle = %7.3f, score = %7.3f\n", procName,
+    L_INFO(" From sweep: angle = %7.3f, score = %7.3f\n", __func__,
            maxangle, maxscore);
 #endif  /* DEBUG_PRINT_SWEEP */
 
@@ -809,7 +796,7 @@ PIX       *pixsw, *pixsch, *pixt1, *pixt2;
         /* Check if the max is at the end of the sweep. */
     n = numaGetCount(natheta);
     if (maxindex == 0 || maxindex == n - 1) {
-        L_WARNING("max found at sweep edge\n", procName);
+        L_WARNING("max found at sweep edge\n", __func__);
         goto cleanup;
     }
 
@@ -848,7 +835,7 @@ PIX       *pixsw, *pixsch, *pixt1, *pixt2;
     numaAddNumber(natheta, centerangle + sweepdelta);
 
         /* Start the search */
-    delta = 0.5 * sweepdelta;
+    delta = 0.5f * sweepdelta;
     while (delta >= minbsdelta)
     {
             /* Get the left intermediate score */
@@ -896,12 +883,12 @@ PIX       *pixsw, *pixsch, *pixt1, *pixt2;
 
             /* Get new center angle and delta for next iteration */
         centerangle = centerangle + delta * (maxindex - 2);
-        delta = 0.5 * delta;
+        delta = 0.5f * delta;
     }
     *pangle = centerangle;
 
 #if  DEBUG_PRINT_SCORES
-    L_INFO(" Binary search score = %7.3f\n", procName, bsearchscore[2]);
+    L_INFO(" Binary search score = %7.3f\n", __func__, bsearchscore[2]);
 #endif  /* DEBUG_PRINT_SCORES */
 
     if (pendscore)  /* save if requested */
@@ -924,9 +911,9 @@ PIX       *pixsw, *pixsch, *pixt1, *pixt2;
     minthresh = MinscoreThreshFactor * width * width * height;
 
 #if  DEBUG_THRESHOLD
-    L_INFO(" minthresh = %10.2f, minscore = %10.2f\n", procName,
+    L_INFO(" minthresh = %10.2f, minscore = %10.2f\n", __func__,
            minthresh, minscore);
-    L_INFO(" maxscore = %10.2f\n", procName, maxscore);
+    L_INFO(" maxscore = %10.2f\n", __func__, maxscore);
 #endif  /* DEBUG_THRESHOLD */
 
     if (minscore > minthresh)
@@ -1049,14 +1036,12 @@ pixFindSkewOrthogonalRange(PIX        *pixs,
 l_float32  angle1, conf1, score1, angle2, conf2, score2;
 PIX       *pixr;
 
-    PROCNAME("pixFindSkewOrthogonalRange");
-
     if (pangle) *pangle = 0.0;
     if (pconf) *pconf = 0.0;
     if (!pangle || !pconf)
-        return ERROR_INT("&angle and/or &conf not defined", procName, 1);
+        return ERROR_INT("&angle and/or &conf not defined", __func__, 1);
     if (!pixs || pixGetDepth(pixs) != 1)
-        return ERROR_INT("pixs not defined or not 1 bpp", procName, 1);
+        return ERROR_INT("pixs not defined or not 1 bpp", __func__, 1);
 
     pixFindSkewSweepAndSearchScorePivot(pixs, &angle1, &conf1, &score1,
                                         redsweep, redsearch, 0.0,
@@ -1073,7 +1058,7 @@ PIX       *pixr;
         *pangle = angle1;
         *pconf = conf1;
     } else {
-        *pangle = -90.0 + angle2;
+        *pangle = -90.0f + angle2;
         *pconf = conf2;
     }
 
@@ -1117,18 +1102,16 @@ l_int32    w, h, skiph, skip, nskip;
 l_float32  val1, val2, diff, sum;
 NUMA      *na;
 
-    PROCNAME("pixFindDifferentialSquareSum");
-
     if (!psum)
-        return ERROR_INT("&sum not defined", procName, 1);
+        return ERROR_INT("&sum not defined", __func__, 1);
     *psum = 0.0;
     if (!pixs)
-        return ERROR_INT("pixs not defined", procName, 1);
+        return ERROR_INT("pixs not defined", __func__, 1);
 
         /* Generate a number array consisting of the sum
          * of pixels in each row of pixs */
     if ((na = pixCountPixelsByRow(pixs, NULL)) == NULL)
-        return ERROR_INT("na not made", procName, 1);
+        return ERROR_INT("na not made", __func__, 1);
 
         /* Compute the number of rows at top and bottom to omit.
          * We omit these to avoid getting a spurious signal from
@@ -1192,15 +1175,13 @@ l_float32  sum, sumsq, uniform, val;
 NUMA      *na;
 PIX       *pixt;
 
-    PROCNAME("pixFindNormalizedSquareSum");
-
     if (phratio) *phratio = 0.0;
     if (pvratio) *pvratio = 0.0;
     if (pfract) *pfract = 0.0;
     if (!phratio && !pvratio)
-        return ERROR_INT("nothing to do", procName, 1);
+        return ERROR_INT("nothing to do", __func__, 1);
     if (!pixs || pixGetDepth(pixs) != 1)
-        return ERROR_INT("pixs not defined or not 1 bpp", procName, 1);
+        return ERROR_INT("pixs not defined or not 1 bpp", __func__, 1);
     pixGetDimensions(pixs, &w, &h, NULL);
 
     empty = 0;
