@@ -44,7 +44,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config_auto.h"
+#include <config_auto.h>
 #endif  /* HAVE_CONFIG_H */
 
 #include "allheaders.h"
@@ -71,15 +71,13 @@ l_uint8  *filedata;
 size_t    filesize;
 PIX      *pix;
 
-    PROCNAME("pixReadStreamWebP");
-
     if (!fp)
-        return (PIX *)ERROR_PTR("fp not defined", procName, NULL);
+        return (PIX *)ERROR_PTR("fp not defined", __func__, NULL);
 
         /* Read data from file and decode into Y,U,V arrays */
     rewind(fp);
     if ((filedata = l_binaryReadStream(fp, &filesize)) == NULL)
-        return (PIX *)ERROR_PTR("filedata not read", procName, NULL);
+        return (PIX *)ERROR_PTR("filedata not read", __func__, NULL);
 
     pix = pixReadMemWebP(filedata, filesize);
     LEPT_FREE(filedata);
@@ -117,19 +115,20 @@ size_t     size;
 PIX       *pix;
 WebPBitstreamFeatures  features;
 
-    PROCNAME("pixReadMemWebP");
-
     if (!filedata)
-        return (PIX *)ERROR_PTR("filedata not defined", procName, NULL);
+        return (PIX *)ERROR_PTR("filedata not defined", __func__, NULL);
 
     if (WebPGetFeatures(filedata, filesize, &features))
-        return (PIX *)ERROR_PTR("Invalid WebP file", procName, NULL);
+        return (PIX *)ERROR_PTR("Invalid WebP file", __func__, NULL);
     w = features.width;
     h = features.height;
     has_alpha = features.has_alpha;
 
         /* Write from compressed Y,U,V arrays to pix raster data */
-    pix = pixCreate(w, h, 32);
+    if ((pix = pixCreate(w, h, 32)) == NULL) {
+        lept_stderr("Allocation failure for pix: w = %d, h = %d\n", w, h);
+        return (PIX *)ERROR_PTR("pix not made", __func__, NULL);
+    }
     pixSetInputFormat(pix, IFF_WEBP);
     if (has_alpha) pixSetSpp(pix, 4);
     data = pixGetData(pix);
@@ -140,7 +139,7 @@ WebPBitstreamFeatures  features;
                              stride);
     if (out == NULL) {  /* error: out should also point to data */
         pixDestroy(&pix);
-        return (PIX *)ERROR_PTR("WebP decode failed", procName, NULL);
+        return (PIX *)ERROR_PTR("WebP decode failed", __func__, NULL);
     }
 
         /* The WebP API expects data in RGBA order.  The pix stores
@@ -173,26 +172,24 @@ l_int32  nbytes, bytesread;
 size_t   filesize;
 FILE    *fp;
 
-    PROCNAME("readHeaderWebP");
-
     if (!pw || !ph || !pspp)
-        return ERROR_INT("input ptr(s) not defined", procName, 1);
+        return ERROR_INT("input ptr(s) not defined", __func__, 1);
     *pw = *ph = *pspp = 0;
     if (!filename)
-        return ERROR_INT("filename not defined", procName, 1);
+        return ERROR_INT("filename not defined", __func__, 1);
 
         /* Read no more than 100 bytes from the file */
     if ((filesize = nbytesInFile(filename)) == 0)
-        return ERROR_INT("no file size found", procName, 1);
+        return ERROR_INT_1("no file size found", filename, __func__, 1);
     if (filesize < 100)
-        L_WARNING("very small webp file\n", procName);
+        L_WARNING("very small webp file: %s\n", __func__, filename);
     nbytes = L_MIN(filesize, 100);
     if ((fp = fopenReadStream(filename)) == NULL)
-        return ERROR_INT("image file not found", procName, 1);
+        return ERROR_INT_1("image file not found", filename, __func__, 1);
     bytesread = fread(data, 1, nbytes, fp);
     fclose(fp);
     if (bytesread != nbytes)
-        return ERROR_INT("failed to read requested data", procName, 1);
+        return ERROR_INT("failed to read requested data", __func__, 1);
 
     return readHeaderMemWebP(data, nbytes, pw, ph, pspp);
 }
@@ -217,18 +214,16 @@ readHeaderMemWebP(const l_uint8  *data,
 {
 WebPBitstreamFeatures  features;
 
-    PROCNAME("readHeaderWebP");
-
     if (pw) *pw = 0;
     if (ph) *ph = 0;
     if (pspp) *pspp = 0;
     if (!data)
-        return ERROR_INT("data not defined", procName, 1);
+        return ERROR_INT("data not defined", __func__, 1);
     if (!pw || !ph || !pspp)
-        return ERROR_INT("input ptr(s) not defined", procName, 1);
+        return ERROR_INT("input ptr(s) not defined", __func__, 1);
 
     if (WebPGetFeatures(data, (l_int32)size, &features))
-        return ERROR_INT("invalid WebP file", procName, 1);
+        return ERROR_INT("invalid WebP file", __func__, 1);
     *pw = features.width;
     *ph = features.height;
     *pspp = (features.has_alpha) ? 4 : 3;
@@ -262,19 +257,17 @@ pixWriteWebP(const char  *filename,
 l_int32  ret;
 FILE    *fp;
 
-    PROCNAME("pixWriteWebP");
-
     if (!pixs)
-        return ERROR_INT("pixs not defined", procName, 1);
+        return ERROR_INT("pixs not defined", __func__, 1);
     if (!filename)
-        return ERROR_INT("filename not defined", procName, 1);
+        return ERROR_INT("filename not defined", __func__, 1);
 
     if ((fp = fopenWriteStream(filename, "wb+")) == NULL)
-        return ERROR_INT("stream not opened", procName, 1);
+        return ERROR_INT_1("stream not opened", filename, __func__, 1);
     ret = pixWriteStreamWebP(fp, pixs, quality, lossless);
     fclose(fp);
     if (ret)
-        return ERROR_INT("pixs not compressed to stream", procName, 1);
+        return ERROR_INT_1("pixs not compressed to stream", filename, __func__, 1);
     return 0;
 }
 
@@ -304,12 +297,10 @@ pixWriteStreamWebP(FILE    *fp,
 l_uint8  *filedata;
 size_t    filebytes, nbytes;
 
-    PROCNAME("pixWriteStreamWebP");
-
     if (!fp)
-        return ERROR_INT("stream not open", procName, 1);
+        return ERROR_INT("stream not open", __func__, 1);
     if (!pixs)
-        return ERROR_INT("pixs not defined", procName, 1);
+        return ERROR_INT("pixs not defined", __func__, 1);
 
     pixSetPadBits(pixs, 0);
     pixWriteMemWebP(&filedata, &filebytes, pixs, quality, lossless);
@@ -317,7 +308,7 @@ size_t    filebytes, nbytes;
     nbytes = fwrite(filedata, 1, filebytes, fp);
     free(filedata);
     if (nbytes != filebytes)
-        return ERROR_INT("Write error", procName, 1);
+        return ERROR_INT("Write error", __func__, 1);
     return 0;
 }
 
@@ -353,21 +344,19 @@ l_int32    w, h, d, wpl, stride;
 l_uint32  *data;
 PIX       *pix1, *pix2;
 
-    PROCNAME("pixWriteMemWebP");
-
     if (!pencdata)
-        return ERROR_INT("&encdata not defined", procName, 1);
+        return ERROR_INT("&encdata not defined", __func__, 1);
     *pencdata = NULL;
     if (!pencsize)
-        return ERROR_INT("&encsize not defined", procName, 1);
+        return ERROR_INT("&encsize not defined", __func__, 1);
     *pencsize = 0;
     if (!pixs)
-        return ERROR_INT("&pixs not defined", procName, 1);
+        return ERROR_INT("&pixs not defined", __func__, 1);
     if (lossless == 0 && (quality < 0 || quality > 100))
-        return ERROR_INT("quality not in [0 ... 100]", procName, 1);
+        return ERROR_INT("quality not in [0 ... 100]", __func__, 1);
 
     if ((pix1 = pixRemoveColormap(pixs, REMOVE_CMAP_TO_FULL_COLOR)) == NULL)
-        return ERROR_INT("failure to remove color map", procName, 1);
+        return ERROR_INT("failure to remove color map", __func__, 1);
 
         /* Convert to rgb if not 32 bpp; pix2 must not be a clone of pixs. */
     if (pixGetDepth(pix1) != 32)
@@ -378,7 +367,7 @@ PIX       *pix1, *pix2;
     pixGetDimensions(pix2, &w, &h, &d);
     if (w <= 0 || h <= 0 || d != 32) {
         pixDestroy(&pix2);
-        return ERROR_INT("pix2 not 32 bpp or of 0 size", procName, 1);
+        return ERROR_INT("pix2 not 32 bpp or of 0 size", __func__, 1);
     }
 
         /* If spp == 3, need to set alpha layer to opaque (all 1s). */
@@ -406,7 +395,7 @@ PIX       *pix1, *pix2;
     if (*pencsize == 0) {
         free(*pencdata);
         *pencdata = NULL;
-        return ERROR_INT("webp encoding failed", procName, 1);
+        return ERROR_INT("webp encoding failed", __func__, 1);
     }
 
     return 0;
